"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
Copyright 2025 Phonexia s.r.o.

Licensed under the Apache License, Version 2.0 (the "License");
you may not use this file except in compliance with the License.
You may obtain a copy of the License at

    http://www.apache.org/licenses/LICENSE-2.0

Unless required by applicable law or agreed to in writing, software
distributed under the License is distributed on an "AS IS" BASIS,
WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
See the License for the specific language governing permissions and
limitations under the License.

Phonexia Keyword Spotting gRPC API.
"""

import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.duration_pb2
import google.protobuf.internal.containers
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import phonexia.grpc.common.core_pb2
import sys
import typing

if sys.version_info >= (3, 10):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing.final
class Keyword(google.protobuf.message.Message):
    """*
    A keyword.
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SPELLING_FIELD_NUMBER: builtins.int
    PRONUNCIATIONS_FIELD_NUMBER: builtins.int
    spelling: builtins.str
    """*
    The spelling of the keyword written in graphemes.
    Only supported graphemes listed by <code>ListAllowedSymbols</code> can be used.
    The keyword may contain multiple words separated by the word separator '+'.
    """
    @property
    def pronunciations(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]:
        """*
        Pronunciations written in phonemes separated by spaces.
        Only supported phonemes listed by <code>ListAllowedSymbols</code> can be used.
        Keyword is matched if any of the pronunciations matches.
        If not set, the pronunciation is searched in the system's vocabulary and if it is not found,
        it is automatically generated by the system.
        """

    def __init__(
        self,
        *,
        spelling: builtins.str = ...,
        pronunciations: collections.abc.Iterable[builtins.str] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["pronunciations", b"pronunciations", "spelling", b"spelling"]) -> None: ...

Global___Keyword: typing_extensions.TypeAlias = Keyword

@typing.final
class DetectRequest(google.protobuf.message.Message):
    """*
    A request to detect keywords in an audio file.
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    AUDIO_FIELD_NUMBER: builtins.int
    KEYWORDS_FIELD_NUMBER: builtins.int
    CONFIG_FIELD_NUMBER: builtins.int
    @property
    def audio(self) -> phonexia.grpc.common.core_pb2.Audio:
        """*
        The audio data to process. There is no minimum audio length limit.
        """

    @property
    def keywords(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[Global___Keyword]:
        """*
        The list of keywords to detect.
        """

    @property
    def config(self) -> Global___DetectConfig:
        """*
        Optional Detect request configuration.
        """

    def __init__(
        self,
        *,
        audio: phonexia.grpc.common.core_pb2.Audio | None = ...,
        keywords: collections.abc.Iterable[Global___Keyword] | None = ...,
        config: Global___DetectConfig | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["audio", b"audio", "config", b"config"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["audio", b"audio", "config", b"config", "keywords", b"keywords"]) -> None: ...

Global___DetectRequest: typing_extensions.TypeAlias = DetectRequest

@typing.final
class DetectConfig(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CONFIDENCE_SHARPNESS_FIELD_NUMBER: builtins.int
    confidence_sharpness: builtins.float
    """*
     Specifies how the dynamic range of score is used (default is 1.0). Must be greater than zero.
    """
    def __init__(
        self,
        *,
        confidence_sharpness: builtins.float | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["_confidence_sharpness", b"_confidence_sharpness", "confidence_sharpness", b"confidence_sharpness"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["_confidence_sharpness", b"_confidence_sharpness", "confidence_sharpness", b"confidence_sharpness"]) -> None: ...
    def WhichOneof(self, oneof_group: typing.Literal["_confidence_sharpness", b"_confidence_sharpness"]) -> typing.Literal["confidence_sharpness"] | None: ...

Global___DetectConfig: typing_extensions.TypeAlias = DetectConfig

@typing.final
class MatchedKeyword(google.protobuf.message.Message):
    """*
    A matched keyword.
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    class _PronunciationSource:
        ValueType = typing.NewType("ValueType", builtins.int)
        V: typing_extensions.TypeAlias = ValueType

    class _PronunciationSourceEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[MatchedKeyword._PronunciationSource.ValueType], builtins.type):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
        DICTIONARY: MatchedKeyword._PronunciationSource.ValueType  # 0
        """*
        The pronunciation is in system's vocabulary.
        """
        GENERATED: MatchedKeyword._PronunciationSource.ValueType  # 1
        """*
        The pronunciation has been generated by the system
        """
        USER: MatchedKeyword._PronunciationSource.ValueType  # 2
        """*
        The pronunciation was set by the user.
        """
        PARTLY_GENERATED: MatchedKeyword._PronunciationSource.ValueType  # 3
        """*
        Part of the pronunciation was generated by the system,
        the rest of the pronunciation is in system's vocabulary.
        Only applicable for words separated with '+' separator.
        """

    class PronunciationSource(_PronunciationSource, metaclass=_PronunciationSourceEnumTypeWrapper):
        """*
        The source of the matched keyword.
        """

    DICTIONARY: MatchedKeyword.PronunciationSource.ValueType  # 0
    """*
    The pronunciation is in system's vocabulary.
    """
    GENERATED: MatchedKeyword.PronunciationSource.ValueType  # 1
    """*
    The pronunciation has been generated by the system
    """
    USER: MatchedKeyword.PronunciationSource.ValueType  # 2
    """*
    The pronunciation was set by the user.
    """
    PARTLY_GENERATED: MatchedKeyword.PronunciationSource.ValueType  # 3
    """*
    Part of the pronunciation was generated by the system,
    the rest of the pronunciation is in system's vocabulary.
    Only applicable for words separated with '+' separator.
    """

    SPELLING_FIELD_NUMBER: builtins.int
    PRONUNCIATION_FIELD_NUMBER: builtins.int
    PRONUNCIATION_SOURCE_FIELD_NUMBER: builtins.int
    spelling: builtins.str
    """*
    The spelling of the matched keyword written in graphemes.
    """
    pronunciation: builtins.str
    """*
    The pronunciation of the matched keyword written in phonemes separated by spaces.
    """
    pronunciation_source: Global___MatchedKeyword.PronunciationSource.ValueType
    """*
    The source of the matched pronunciation.
    """
    def __init__(
        self,
        *,
        spelling: builtins.str = ...,
        pronunciation: builtins.str = ...,
        pronunciation_source: Global___MatchedKeyword.PronunciationSource.ValueType = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["pronunciation", b"pronunciation", "pronunciation_source", b"pronunciation_source", "spelling", b"spelling"]) -> None: ...

Global___MatchedKeyword: typing_extensions.TypeAlias = MatchedKeyword

@typing.final
class Match(google.protobuf.message.Message):
    """*
    A match.
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    START_TIME_FIELD_NUMBER: builtins.int
    END_TIME_FIELD_NUMBER: builtins.int
    CONFIDENCE_FIELD_NUMBER: builtins.int
    SCORE_FIELD_NUMBER: builtins.int
    KEYWORD_FIELD_NUMBER: builtins.int
    confidence: builtins.float
    """*
    The confidence of the match in range [0, 1].
    """
    score: builtins.float
    """*
    Score is calculated as log likelihood ratio in range [-inf, inf].
    """
    @property
    def start_time(self) -> google.protobuf.duration_pb2.Duration:
        """*
        The start time of the match.
        """

    @property
    def end_time(self) -> google.protobuf.duration_pb2.Duration:
        """*
        The end time of the match.
        """

    @property
    def keyword(self) -> Global___MatchedKeyword:
        """*
        The matched keyword.
        """

    def __init__(
        self,
        *,
        start_time: google.protobuf.duration_pb2.Duration | None = ...,
        end_time: google.protobuf.duration_pb2.Duration | None = ...,
        confidence: builtins.float = ...,
        score: builtins.float = ...,
        keyword: Global___MatchedKeyword | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["end_time", b"end_time", "keyword", b"keyword", "start_time", b"start_time"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["confidence", b"confidence", "end_time", b"end_time", "keyword", b"keyword", "score", b"score", "start_time", b"start_time"]) -> None: ...

Global___Match: typing_extensions.TypeAlias = Match

@typing.final
class DetectResult(google.protobuf.message.Message):
    """*
    The result of the detect operation.
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    MATCHES_FIELD_NUMBER: builtins.int
    @property
    def matches(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[Global___Match]:
        """*
        The list of matches.
        """

    def __init__(
        self,
        *,
        matches: collections.abc.Iterable[Global___Match] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["matches", b"matches"]) -> None: ...

Global___DetectResult: typing_extensions.TypeAlias = DetectResult

@typing.final
class DetectResponse(google.protobuf.message.Message):
    """*
    The response of the detect operation.
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESULT_FIELD_NUMBER: builtins.int
    PROCESSED_AUDIO_LENGTH_FIELD_NUMBER: builtins.int
    @property
    def result(self) -> Global___DetectResult:
        """*
        The result of the detect operation.
        """

    @property
    def processed_audio_length(self) -> google.protobuf.duration_pb2.Duration:
        """*
        The length of the processed audio.
        """

    def __init__(
        self,
        *,
        result: Global___DetectResult | None = ...,
        processed_audio_length: google.protobuf.duration_pb2.Duration | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["processed_audio_length", b"processed_audio_length", "result", b"result"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["processed_audio_length", b"processed_audio_length", "result", b"result"]) -> None: ...

Global___DetectResponse: typing_extensions.TypeAlias = DetectResponse

@typing.final
class ListAllowedSymbolsRequest(google.protobuf.message.Message):
    """*
    The request to list allowed symbols.
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

Global___ListAllowedSymbolsRequest: typing_extensions.TypeAlias = ListAllowedSymbolsRequest

@typing.final
class ListAllowedSymbolsResponse(google.protobuf.message.Message):
    """*
    The response of the list allowed symbols operation.
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    GRAPHEMES_FIELD_NUMBER: builtins.int
    PHONEMES_FIELD_NUMBER: builtins.int
    @property
    def graphemes(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]:
        """*
        The list of allowed graphemes.
        """

    @property
    def phonemes(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]:
        """*
        The list of allowed phonemes.
        """

    def __init__(
        self,
        *,
        graphemes: collections.abc.Iterable[builtins.str] | None = ...,
        phonemes: collections.abc.Iterable[builtins.str] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["graphemes", b"graphemes", "phonemes", b"phonemes"]) -> None: ...

Global___ListAllowedSymbolsResponse: typing_extensions.TypeAlias = ListAllowedSymbolsResponse



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
Copyright 2025 Phonexia s.r.o.

Licensed under the Apache License, Version 2.0 (the "License");
you may not use this file except in compliance with the License.
You may obtain a copy of the License at

    http://www.apache.org/licenses/LICENSE-2.0

Unless required by applicable law or agreed to in writing, software
distributed under the License is distributed on an "AS IS" BASIS,
WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
See the License for the specific language governing permissions and
limitations under the License.

Phonexia licensing definitions for gRPC API.
"""

import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import sys
import typing

if sys.version_info >= (3, 10):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing.final
class LicensingInfoRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

Global___LicensingInfoRequest: typing_extensions.TypeAlias = LicensingInfoRequest

@typing.final
class LicensingInfoResult(google.protobuf.message.Message):
    """The top-level message returned to the client by <code>LicenseInfo</code>
    method.
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing.final
    class LicenseFlagsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing.Literal["key", b"key", "value", b"value"]) -> None: ...

    VALID_UNTIL_FIELD_NUMBER: builtins.int
    IS_VALID_FIELD_NUMBER: builtins.int
    TECHNOLOGY_NAME_FIELD_NUMBER: builtins.int
    MODEL_INFO_FIELD_NUMBER: builtins.int
    LICENSE_FLAGS_FIELD_NUMBER: builtins.int
    valid_until: builtins.str
    """Validity of a license in YYYY-MM-DD format according to ISO 8601."""
    is_valid: builtins.bool
    """License status, contains "false" if the license has expired."""
    technology_name: builtins.str
    """Name of the technology being licensed."""
    @property
    def model_info(self) -> Global___ModelInfo:
        """Information about the licensed model."""

    @property
    def license_flags(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]:
        """License flags"""

    def __init__(
        self,
        *,
        valid_until: builtins.str = ...,
        is_valid: builtins.bool = ...,
        technology_name: builtins.str = ...,
        model_info: Global___ModelInfo | None = ...,
        license_flags: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["model_info", b"model_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["is_valid", b"is_valid", "license_flags", b"license_flags", "model_info", b"model_info", "technology_name", b"technology_name", "valid_until", b"valid_until"]) -> None: ...

Global___LicensingInfoResult: typing_extensions.TypeAlias = LicensingInfoResult

@typing.final
class ModelInfo(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NAME_FIELD_NUMBER: builtins.int
    VERSION_FIELD_NUMBER: builtins.int
    name: builtins.str
    """Name of the model."""
    version: builtins.str
    """Version of the model."""
    def __init__(
        self,
        *,
        name: builtins.str = ...,
        version: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["name", b"name", "version", b"version"]) -> None: ...

Global___ModelInfo: typing_extensions.TypeAlias = ModelInfo



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: phonexia/grpc/technologies/speaker_diarization/v1/speaker_diarization.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'phonexia/grpc/technologies/speaker_diarization/v1/speaker_diarization.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from phonexia.grpc.common import core_pb2 as phonexia_dot_grpc_dot_common_dot_core__pb2
from google.protobuf import duration_pb2 as google_dot_protobuf_dot_duration__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nKphonexia/grpc/technologies/speaker_diarization/v1/speaker_diarization.proto\x12\x31phonexia.grpc.technologies.speaker_diarization.v1\x1a\x1fphonexia/grpc/common/core.proto\x1a\x1egoogle/protobuf/duration.proto\"\x8e\x01\n\x0e\x44iarizeRequest\x12*\n\x05\x61udio\x18\x01 \x01(\x0b\x32\x1b.phonexia.grpc.common.Audio\x12P\n\x06\x63onfig\x18\x02 \x01(\x0b\x32@.phonexia.grpc.technologies.speaker_diarization.v1.DiarizeConfig\"k\n\rDiarizeConfig\x12\x19\n\x0cmax_speakers\x18\x01 \x01(\x05H\x00\x88\x01\x01\x12\x1b\n\x0etotal_speakers\x18\x02 \x01(\x05H\x01\x88\x01\x01\x42\x0f\n\r_max_speakersB\x11\n\x0f_total_speakers\"\xe4\x01\n\x0f\x44iarizeResponse\x12\x16\n\x0espeakers_count\x18\x01 \x01(\x05\x12L\n\x08segments\x18\x02 \x03(\x0b\x32:.phonexia.grpc.technologies.speaker_diarization.v1.Segment\x12\x39\n\x16processed_audio_length\x18\x03 \x01(\x0b\x32\x19.google.protobuf.Duration\x12\x30\n\rspeech_length\x18\x04 \x01(\x0b\x32\x19.google.protobuf.Duration\"y\n\x07Segment\x12\x12\n\nspeaker_id\x18\x01 \x01(\x05\x12-\n\nstart_time\x18\x02 \x01(\x0b\x32\x19.google.protobuf.Duration\x12+\n\x08\x65nd_time\x18\x03 \x01(\x0b\x32\x19.google.protobuf.Duration2\xa9\x01\n\x12SpeakerDiarization\x12\x92\x01\n\x07\x44iarize\x12\x41.phonexia.grpc.technologies.speaker_diarization.v1.DiarizeRequest\x1a\x42.phonexia.grpc.technologies.speaker_diarization.v1.DiarizeResponse(\x01\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'phonexia.grpc.technologies.speaker_diarization.v1.speaker_diarization_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  DESCRIPTOR._loaded_options = None
  _globals['_DIARIZEREQUEST']._serialized_start=196
  _globals['_DIARIZEREQUEST']._serialized_end=338
  _globals['_DIARIZECONFIG']._serialized_start=340
  _globals['_DIARIZECONFIG']._serialized_end=447
  _globals['_DIARIZERESPONSE']._serialized_start=450
  _globals['_DIARIZERESPONSE']._serialized_end=678
  _globals['_SEGMENT']._serialized_start=680
  _globals['_SEGMENT']._serialized_end=801
  _globals['_SPEAKERDIARIZATION']._serialized_start=804
  _globals['_SPEAKERDIARIZATION']._serialized_end=973
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: phonexia/grpc/technologies/time_analysis/v1/time_analysis.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'phonexia/grpc/technologies/time_analysis/v1/time_analysis.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from phonexia.grpc.common import core_pb2 as phonexia_dot_grpc_dot_common_dot_core__pb2
from google.protobuf import duration_pb2 as google_dot_protobuf_dot_duration__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n?phonexia/grpc/technologies/time_analysis/v1/time_analysis.proto\x12+phonexia.grpc.technologies.time_analysis.v1\x1a\x1fphonexia/grpc/common/core.proto\x1a\x1egoogle/protobuf/duration.proto\"<\n\x0e\x41nalyzeRequest\x12*\n\x05\x61udio\x18\x01 \x01(\x0b\x32\x1b.phonexia.grpc.common.Audio\"\xbc\x02\n\x10ReactionAnalysis\x12\x18\n\x10reacting_channel\x18\x01 \x01(\x05\x12\x17\n\x0freactions_count\x18\x02 \x01(\x04\x12\x38\n\x15\x61verage_reaction_time\x18\x03 \x01(\x0b\x32\x19.google.protobuf.Duration\x12\x42\n\x19\x66\x61stest_reaction_position\x18\x04 \x01(\x0b\x32\x1f.phonexia.grpc.common.TimeRange\x12\x42\n\x19slowest_reaction_position\x18\x05 \x01(\x0b\x32\x1f.phonexia.grpc.common.TimeRange\x12\x33\n\ncrosstalks\x18\x06 \x03(\x0b\x32\x1f.phonexia.grpc.common.TimeRange\"\xb6\x01\n\x0f\x43hannelAnalysis\x12\x16\n\x0e\x63hannel_number\x18\x01 \x01(\x05\x12\x30\n\rspeech_length\x18\x02 \x01(\x0b\x32\x19.google.protobuf.Duration\x12\x18\n\x0bspeech_rate\x18\x03 \x01(\x02H\x00\x88\x01\x01\x12/\n\x0ctotal_length\x18\x04 \x01(\x0b\x32\x19.google.protobuf.DurationB\x0e\n\x0c_speech_rate\"\xc1\x01\n\rAnalyzeResult\x12V\n\x10\x63hannel_analyses\x18\x01 \x03(\x0b\x32<.phonexia.grpc.technologies.time_analysis.v1.ChannelAnalysis\x12X\n\x11reaction_analyses\x18\x02 \x03(\x0b\x32=.phonexia.grpc.technologies.time_analysis.v1.ReactionAnalysis\"\x98\x01\n\x0f\x41nalyzeResponse\x12J\n\x06result\x18\x01 \x01(\x0b\x32:.phonexia.grpc.technologies.time_analysis.v1.AnalyzeResult\x12\x39\n\x16processed_audio_length\x18\x02 \x01(\x0b\x32\x19.google.protobuf.Duration2\x99\x01\n\x0cTimeAnalysis\x12\x88\x01\n\x07\x41nalyze\x12;.phonexia.grpc.technologies.time_analysis.v1.AnalyzeRequest\x1a<.phonexia.grpc.technologies.time_analysis.v1.AnalyzeResponse(\x01\x30\x01\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'phonexia.grpc.technologies.time_analysis.v1.time_analysis_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  DESCRIPTOR._loaded_options = None
  _globals['_ANALYZEREQUEST']._serialized_start=177
  _globals['_ANALYZEREQUEST']._serialized_end=237
  _globals['_REACTIONANALYSIS']._serialized_start=240
  _globals['_REACTIONANALYSIS']._serialized_end=556
  _globals['_CHANNELANALYSIS']._serialized_start=559
  _globals['_CHANNELANALYSIS']._serialized_end=741
  _globals['_ANALYZERESULT']._serialized_start=744
  _globals['_ANALYZERESULT']._serialized_end=937
  _globals['_ANALYZERESPONSE']._serialized_start=940
  _globals['_ANALYZERESPONSE']._serialized_end=1092
  _globals['_TIMEANALYSIS']._serialized_start=1095
  _globals['_TIMEANALYSIS']._serialized_end=1248
# @@protoc_insertion_point(module_scope)



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc
import warnings

from phonexia.grpc.technologies.speech_to_text.v1 import speech_to_text_pb2 as phonexia_dot_grpc_dot_technologies_dot_speech__to__text_dot_v1_dot_speech__to__text__pb2

GRPC_GENERATED_VERSION = '1.76.0'
GRPC_VERSION = grpc.__version__
_version_not_supported = False

try:
    from grpc._utilities import first_version_is_lower
    _version_not_supported = first_version_is_lower(GRPC_VERSION, GRPC_GENERATED_VERSION)
except ImportError:
    _version_not_supported = True

if _version_not_supported:
    raise RuntimeError(
        f'The grpc package installed is at version {GRPC_VERSION},'
        + ' but the generated code in phonexia/grpc/technologies/speech_to_text/v1/speech_to_text_pb2_grpc.py depends on'
        + f' grpcio>={GRPC_GENERATED_VERSION}.'
        + f' Please upgrade your grpc module to grpcio>={GRPC_GENERATED_VERSION}'
        + f' or downgrade your generated code using grpcio-tools<={GRPC_VERSION}.'
    )


class SpeechToTextStub(object):
    """Service implementing speech-to-text transcription.

    Error Handling:

    This service implements the richer gRPC error model using google.rpc.Status
    with detailed error information. When validation fails, the response includes:

    (1) Status code: INVALID_ARGUMENT
    (2) google.rpc.ErrorInfo with top-level error context:
    reason: "INPUT_ERROR"
    domain: "speech-to-text.phonexia"
    (3) google.rpc.BadRequest with field-level validation errors

    The `reason` field in each BadRequest.FieldViolation identifies the specific error type:

    * UNSUPPORTED_GRAPHEME - Character not supported by the transcription model
    * UNSUPPORTED_PHONEME - Phoneme not supported by the transcription model
    * EMPTY_FIELD - Required field is empty or missing
    * PRONUNCIATION_TOO_SHORT - Pronunciation contains fewer than 3 phonemes

    Field violations use dot notation with array indices to identify the exact
    location of errors. Examples:

    * "audio" - Audio field is missing or invalid
    * "config.additional_words[0].spelling" - Error in the spelling of the first additional word
    * "config.additional_words[2].pronunciations[1]" - Error in the second pronunciation of the third additional word
    * "config.preferred_phrases[5]" - Error in the sixth preferred phrase

    Example error response when a preferred phrase contains an unsupported character:
    ```
    code: INVALID_ARGUMENT
    message: "Invalid argument"
    details: [
    ErrorInfo {
    reason: "INPUT_ERROR"
    domain: "speech-to-text.phonexia"
    },
    BadRequest {
    field_violations: [
    {
    field: "config.preferred_phrases[1]"
    description: "Invalid grapheme 'é' in preferred phrase 'café'"
    reason: "UNSUPPORTED_GRAPHEME"
    }
    ]
    }
    ]
    ```
    See [Error handling](https://docs.cloud.phonexia.com/products/speech-platform-4/microservices/guides/error-handling) documentation for more information.

    """

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.Transcribe = channel.stream_stream(
                '/phonexia.grpc.technologies.speech_to_text.v1.SpeechToText/Transcribe',
                request_serializer=phonexia_dot_grpc_dot_technologies_dot_speech__to__text_dot_v1_dot_speech__to__text__pb2.TranscribeRequest.SerializeToString,
                response_deserializer=phonexia_dot_grpc_dot_technologies_dot_speech__to__text_dot_v1_dot_speech__to__text__pb2.TranscribeResponse.FromString,
                _registered_method=True)
        self.ListAllowedSymbols = channel.unary_unary(
                '/phonexia.grpc.technologies.speech_to_text.v1.SpeechToText/ListAllowedSymbols',
                request_serializer=phonexia_dot_grpc_dot_technologies_dot_speech__to__text_dot_v1_dot_speech__to__text__pb2.ListAllowedSymbolsRequest.SerializeToString,
                response_deserializer=phonexia_dot_grpc_dot_technologies_dot_speech__to__text_dot_v1_dot_speech__to__text__pb2.ListAllowedSymbolsResponse.FromString,
                _registered_method=True)


class SpeechToTextServicer(object):
    """Service implementing speech-to-text transcription.

    Error Handling:

    This service implements the richer gRPC error model using google.rpc.Status
    with detailed error information. When validation fails, the response includes:

    (1) Status code: INVALID_ARGUMENT
    (2) google.rpc.ErrorInfo with top-level error context:
    reason: "INPUT_ERROR"
    domain: "speech-to-text.phonexia"
    (3) google.rpc.BadRequest with field-level validation errors

    The `reason` field in each BadRequest.FieldViolation identifies the specific error type:

    * UNSUPPORTED_GRAPHEME - Character not supported by the transcription model
    * UNSUPPORTED_PHONEME - Phoneme not supported by the transcription model
    * EMPTY_FIELD - Required field is empty or missing
    * PRONUNCIATION_TOO_SHORT - Pronunciation contains fewer than 3 phonemes

    Field violations use dot notation with array indices to identify the exact
    location of errors. Examples:

    * "audio" - Audio field is missing or invalid
    * "config.additional_words[0].spelling" - Error in the spelling of the first additional word
    * "config.additional_words[2].pronunciations[1]" - Error in the second pronunciation of the third additional word
    * "config.preferred_phrases[5]" - Error in the sixth preferred phrase

    Example error response when a preferred phrase contains an unsupported character:
    ```
    code: INVALID_ARGUMENT
    message: "Invalid argument"
    details: [
    ErrorInfo {
    reason: "INPUT_ERROR"
    domain: "speech-to-text.phonexia"
    },
    BadRequest {
    field_violations: [
    {
    field: "config.preferred_phrases[1]"
    description: "Invalid grapheme 'é' in preferred phrase 'café'"
    reason: "UNSUPPORTED_GRAPHEME"
    }
    ]
    }
    ]
    ```
    See [Error handling](https://docs.cloud.phonexia.com/products/speech-platform-4/microservices/guides/error-handling) documentation for more information.

    """

    def Transcribe(self, request_iterator, context):
        """Performs synchronous speech-to-text transcription.
        The transcription starts after the whole audio has been received.

        Errors:
        * INVALID_ARGUMENT: Invalid input parameters (see error details for specific violations)
        * RESOURCE_EXHAUSTED: No processing instances available
        * FAILED_PRECONDITION: License has expired
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ListAllowedSymbols(self, request, context):
        """<code>ListAllowedSymbols</code> returns lists of allowed graphemes and phonemes.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_SpeechToTextServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'Transcribe': grpc.stream_stream_rpc_method_handler(
                    servicer.Transcribe,
                    request_deserializer=phonexia_dot_grpc_dot_technologies_dot_speech__to__text_dot_v1_dot_speech__to__text__pb2.TranscribeRequest.FromString,
                    response_serializer=phonexia_dot_grpc_dot_technologies_dot_speech__to__text_dot_v1_dot_speech__to__text__pb2.TranscribeResponse.SerializeToString,
            ),
            'ListAllowedSymbols': grpc.unary_unary_rpc_method_handler(
                    servicer.ListAllowedSymbols,
                    request_deserializer=phonexia_dot_grpc_dot_technologies_dot_speech__to__text_dot_v1_dot_speech__to__text__pb2.ListAllowedSymbolsRequest.FromString,
                    response_serializer=phonexia_dot_grpc_dot_technologies_dot_speech__to__text_dot_v1_dot_speech__to__text__pb2.ListAllowedSymbolsResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'phonexia.grpc.technologies.speech_to_text.v1.SpeechToText', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))
    server.add_registered_method_handlers('phonexia.grpc.technologies.speech_to_text.v1.SpeechToText', rpc_method_handlers)


 # This class is part of an EXPERIMENTAL API.
class SpeechToText(object):
    """Service implementing speech-to-text transcription.

    Error Handling:

    This service implements the richer gRPC error model using google.rpc.Status
    with detailed error information. When validation fails, the response includes:

    (1) Status code: INVALID_ARGUMENT
    (2) google.rpc.ErrorInfo with top-level error context:
    reason: "INPUT_ERROR"
    domain: "speech-to-text.phonexia"
    (3) google.rpc.BadRequest with field-level validation errors

    The `reason` field in each BadRequest.FieldViolation identifies the specific error type:

    * UNSUPPORTED_GRAPHEME - Character not supported by the transcription model
    * UNSUPPORTED_PHONEME - Phoneme not supported by the transcription model
    * EMPTY_FIELD - Required field is empty or missing
    * PRONUNCIATION_TOO_SHORT - Pronunciation contains fewer than 3 phonemes

    Field violations use dot notation with array indices to identify the exact
    location of errors. Examples:

    * "audio" - Audio field is missing or invalid
    * "config.additional_words[0].spelling" - Error in the spelling of the first additional word
    * "config.additional_words[2].pronunciations[1]" - Error in the second pronunciation of the third additional word
    * "config.preferred_phrases[5]" - Error in the sixth preferred phrase

    Example error response when a preferred phrase contains an unsupported character:
    ```
    code: INVALID_ARGUMENT
    message: "Invalid argument"
    details: [
    ErrorInfo {
    reason: "INPUT_ERROR"
    domain: "speech-to-text.phonexia"
    },
    BadRequest {
    field_violations: [
    {
    field: "config.preferred_phrases[1]"
    description: "Invalid grapheme 'é' in preferred phrase 'café'"
    reason: "UNSUPPORTED_GRAPHEME"
    }
    ]
    }
    ]
    ```
    See [Error handling](https://docs.cloud.phonexia.com/products/speech-platform-4/microservices/guides/error-handling) documentation for more information.

    """

    @staticmethod
    def Transcribe(request_iterator,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.stream_stream(
            request_iterator,
            target,
            '/phonexia.grpc.technologies.speech_to_text.v1.SpeechToText/Transcribe',
            phonexia_dot_grpc_dot_technologies_dot_speech__to__text_dot_v1_dot_speech__to__text__pb2.TranscribeRequest.SerializeToString,
            phonexia_dot_grpc_dot_technologies_dot_speech__to__text_dot_v1_dot_speech__to__text__pb2.TranscribeResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def ListAllowedSymbols(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/phonexia.grpc.technologies.speech_to_text.v1.SpeechToText/ListAllowedSymbols',
            phonexia_dot_grpc_dot_technologies_dot_speech__to__text_dot_v1_dot_speech__to__text__pb2.ListAllowedSymbolsRequest.SerializeToString,
            phonexia_dot_grpc_dot_technologies_dot_speech__to__text_dot_v1_dot_speech__to__text__pb2.ListAllowedSymbolsResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
Copyright 2025 Phonexia s.r.o.

Licensed under the Apache License, Version 2.0 (the "License");
you may not use this file except in compliance with the License.
You may obtain a copy of the License at

    http://www.apache.org/licenses/LICENSE-2.0

Unless required by applicable law or agreed to in writing, software
distributed under the License is distributed on an "AS IS" BASIS,
WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
See the License for the specific language governing permissions and
limitations under the License.

Phonexia Audio Manipulation Detection gRPC API.
"""

import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.duration_pb2
import google.protobuf.internal.containers
import google.protobuf.message
import phonexia.grpc.common.core_pb2
import sys
import typing

if sys.version_info >= (3, 10):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing.final
class DetectRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    AUDIO_FIELD_NUMBER: builtins.int
    CONFIG_FIELD_NUMBER: builtins.int
    @property
    def audio(self) -> phonexia.grpc.common.core_pb2.Audio:
        """Audio data for audio manipulation detection.
        The audio should have minimum length of 0.645s seconds which is a length of one segment.
        If the audio is shorter, the <code>segments</code> array in the response will be empty.
        """

    @property
    def config(self) -> Global___DetectConfig:
        """Audio manipulation detection configuration."""

    def __init__(
        self,
        *,
        audio: phonexia.grpc.common.core_pb2.Audio | None = ...,
        config: Global___DetectConfig | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["audio", b"audio", "config", b"config"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["audio", b"audio", "config", b"config"]) -> None: ...

Global___DetectRequest: typing_extensions.TypeAlias = DetectRequest

@typing.final
class DetectConfig(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RAW_SEGMENTATION_FIELD_NUMBER: builtins.int
    raw_segmentation: builtins.bool
    """When `raw_segmentation` is true, the audio is analyzed in overlapping segments of 0.645 seconds
    (with 50% overlap between consecutive segments). Each segment is independently classified as
    manipulated or genuine. Adjacent segments that are both classified as manipulated will NOT be
    merged, resulting in potentially redundant but more granular detections. When `raw_segmentation`
    is false (default), adjacent manipulated segments are consolidated into a single continuous
    segment to provide a cleaner output.
    Example: With `raw_segmentation=true`, if segments [0.0, 0.645] and [0.3225, 0.9675] are both 
    detected as manipulated, they will be reported as two separate segments despite their overlap.
    With `raw_segmentation=false`, these would be merged into a single segment [0.0, 0.9675].
    """
    def __init__(
        self,
        *,
        raw_segmentation: builtins.bool = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["raw_segmentation", b"raw_segmentation"]) -> None: ...

Global___DetectConfig: typing_extensions.TypeAlias = DetectConfig

@typing.final
class DetectResponse(google.protobuf.message.Message):
    """The top level message returned to the client by the <code>Detect</code> method."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SEGMENTS_FIELD_NUMBER: builtins.int
    PROCESSED_AUDIO_LENGTH_FIELD_NUMBER: builtins.int
    @property
    def segments(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[Global___Segment]:
        """List of detected segments. Will be empty if the audio is shorter than 0.645 seconds."""

    @property
    def processed_audio_length(self) -> google.protobuf.duration_pb2.Duration:
        """Total length of the processed audio."""

    def __init__(
        self,
        *,
        segments: collections.abc.Iterable[Global___Segment] | None = ...,
        processed_audio_length: google.protobuf.duration_pb2.Duration | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["processed_audio_length", b"processed_audio_length"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["processed_audio_length", b"processed_audio_length", "segments", b"segments"]) -> None: ...

Global___DetectResponse: typing_extensions.TypeAlias = DetectResponse

@typing.final
class Segment(google.protobuf.message.Message):
    """Detected segment."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SCORE_FIELD_NUMBER: builtins.int
    START_TIME_FIELD_NUMBER: builtins.int
    END_TIME_FIELD_NUMBER: builtins.int
    score: builtins.float
    """Score of the audio manipulation represented as a Log-likelihood ratio (LLR).
    A higher score indicates a higher likelihood of the audio being manipulated.
    The threshold is at score == 0. A score greater than 0 indicates that the audio
    may be manipulated, while a score less than 0 indicates that the audio is likely
    not manipulated.
    By default, only the segments containing manipulated audio (score > 0) are returned.
    If multiple adjacent segments contain manipulated audio, they are merged into
    a single segment. To change this behavior, set <code>DetectRequest.config.raw_segmentation</code>
    """
    @property
    def start_time(self) -> google.protobuf.duration_pb2.Duration:
        """Timestamp specifying the beginning of the segment."""

    @property
    def end_time(self) -> google.protobuf.duration_pb2.Duration:
        """Timestamp specifying the end of the segment."""

    def __init__(
        self,
        *,
        score: builtins.float = ...,
        start_time: google.protobuf.duration_pb2.Duration | None = ...,
        end_time: google.protobuf.duration_pb2.Duration | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["end_time", b"end_time", "start_time", b"start_time"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["end_time", b"end_time", "score", b"score", "start_time", b"start_time"]) -> None: ...

Global___Segment: typing_extensions.TypeAlias = Segment



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: phonexia/grpc/common/health_check.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'phonexia/grpc/common/health_check.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\'phonexia/grpc/common/health_check.proto\x12\x0egrpc.health.v1\"%\n\x12HealthCheckRequest\x12\x0f\n\x07service\x18\x01 \x01(\t\"\x94\x01\n\x13HealthCheckResponse\x12\x41\n\x06status\x18\x01 \x01(\x0e\x32\x31.grpc.health.v1.HealthCheckResponse.ServingStatus\":\n\rServingStatus\x12\x0b\n\x07UNKNOWN\x10\x00\x12\x0b\n\x07SERVING\x10\x01\x12\x0f\n\x0bNOT_SERVING\x10\x02\x32\xae\x01\n\x06Health\x12P\n\x05\x43heck\x12\".grpc.health.v1.HealthCheckRequest\x1a#.grpc.health.v1.HealthCheckResponse\x12R\n\x05Watch\x12\".grpc.health.v1.HealthCheckRequest\x1a#.grpc.health.v1.HealthCheckResponse0\x01\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'phonexia.grpc.common.health_check_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  DESCRIPTOR._loaded_options = None
  _globals['_HEALTHCHECKREQUEST']._serialized_start=59
  _globals['_HEALTHCHECKREQUEST']._serialized_end=96
  _globals['_HEALTHCHECKRESPONSE']._serialized_start=99
  _globals['_HEALTHCHECKRESPONSE']._serialized_end=247
  _globals['_HEALTHCHECKRESPONSE_SERVINGSTATUS']._serialized_start=189
  _globals['_HEALTHCHECKRESPONSE_SERVINGSTATUS']._serialized_end=247
  _globals['_HEALTH']._serialized_start=250
  _globals['_HEALTH']._serialized_end=424
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: phonexia/grpc/common/licensing.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'phonexia/grpc/common/licensing.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n$phonexia/grpc/common/licensing.proto\x12\x14phonexia.grpc.common\"\x16\n\x14LicensingInfoRequest\"\x93\x02\n\x13LicensingInfoResult\x12\x13\n\x0bvalid_until\x18\x01 \x01(\t\x12\x10\n\x08is_valid\x18\x02 \x01(\x08\x12\x17\n\x0ftechnology_name\x18\x03 \x01(\t\x12\x33\n\nmodel_info\x18\x04 \x01(\x0b\x32\x1f.phonexia.grpc.common.ModelInfo\x12R\n\rlicense_flags\x18\x05 \x03(\x0b\x32;.phonexia.grpc.common.LicensingInfoResult.LicenseFlagsEntry\x1a\x33\n\x11LicenseFlagsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"*\n\tModelInfo\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x0f\n\x07version\x18\x02 \x01(\t2j\n\tLicensing\x12]\n\x04Info\x12*.phonexia.grpc.common.LicensingInfoRequest\x1a).phonexia.grpc.common.LicensingInfoResultb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'phonexia.grpc.common.licensing_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  DESCRIPTOR._loaded_options = None
  _globals['_LICENSINGINFORESULT_LICENSEFLAGSENTRY']._loaded_options = None
  _globals['_LICENSINGINFORESULT_LICENSEFLAGSENTRY']._serialized_options = b'8\001'
  _globals['_LICENSINGINFOREQUEST']._serialized_start=62
  _globals['_LICENSINGINFOREQUEST']._serialized_end=84
  _globals['_LICENSINGINFORESULT']._serialized_start=87
  _globals['_LICENSINGINFORESULT']._serialized_end=362
  _globals['_LICENSINGINFORESULT_LICENSEFLAGSENTRY']._serialized_start=311
  _globals['_LICENSINGINFORESULT_LICENSEFLAGSENTRY']._serialized_end=362
  _globals['_MODELINFO']._serialized_start=364
  _globals['_MODELINFO']._serialized_end=406
  _globals['_LICENSING']._serialized_start=408
  _globals['_LICENSING']._serialized_end=514
# @@protoc_insertion_point(module_scope)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
Copyright 2025 Phonexia s.r.o.

Licensed under the Apache License, Version 2.0 (the "License");
you may not use this file except in compliance with the License.
You may obtain a copy of the License at

    http://www.apache.org/licenses/LICENSE-2.0

Unless required by applicable law or agreed to in writing, software
distributed under the License is distributed on an "AS IS" BASIS,
WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
See the License for the specific language governing permissions and
limitations under the License.

Phonexia Age Estimation gRPC API.
"""

import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.duration_pb2
import google.protobuf.internal.containers
import google.protobuf.message
import phonexia.grpc.common.core_pb2
import sys
import typing

if sys.version_info >= (3, 10):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing.final
class EstimateRequest(google.protobuf.message.Message):
    """The top-level message sent by the client for the <code>Estimate</code> method."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    VOICEPRINTS_FIELD_NUMBER: builtins.int
    AUDIO_FIELD_NUMBER: builtins.int
    CONFIG_FIELD_NUMBER: builtins.int
    @property
    def voiceprints(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[phonexia.grpc.common.core_pb2.Voiceprint]:
        """List of voiceprints for the estimation."""

    @property
    def audio(self) -> phonexia.grpc.common.core_pb2.Audio:
        """Audio data from which age is to be estimated.
        The audio should have minimum length of at least 0.3 seconds. If the audio is shorter,
        the <code>age</code> field in the corresponding <code>EstimateResult</code> will not be set.
        """

    @property
    def config(self) -> Global___EstimateConfig:
        """Configuration for the age estimation."""

    def __init__(
        self,
        *,
        voiceprints: collections.abc.Iterable[phonexia.grpc.common.core_pb2.Voiceprint] | None = ...,
        audio: phonexia.grpc.common.core_pb2.Audio | None = ...,
        config: Global___EstimateConfig | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["audio", b"audio", "config", b"config"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["audio", b"audio", "config", b"config", "voiceprints", b"voiceprints"]) -> None: ...

Global___EstimateRequest: typing_extensions.TypeAlias = EstimateRequest

@typing.final
class EstimateConfig(google.protobuf.message.Message):
    """Message used for configuration of the <code>Estimate</code> method."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SPEECH_LENGTH_FIELD_NUMBER: builtins.int
    @property
    def speech_length(self) -> google.protobuf.duration_pb2.Duration:
        """Specifies the maximum speech length from which the age will be estimated.
        If there is less speech in the audio than the specified duration, the age
        will be estimated from the entire audio. This option is applicable only for
        Audio data.
        """

    def __init__(
        self,
        *,
        speech_length: google.protobuf.duration_pb2.Duration | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["speech_length", b"speech_length"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["speech_length", b"speech_length"]) -> None: ...

Global___EstimateConfig: typing_extensions.TypeAlias = EstimateConfig

@typing.final
class EstimateResult(google.protobuf.message.Message):
    """An age estimation result."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    AGE_FIELD_NUMBER: builtins.int
    SPEECH_LENGTH_FIELD_NUMBER: builtins.int
    age: builtins.int
    """Estimated age.
    This field is not set if not enough speech has been provided.
    """
    @property
    def speech_length(self) -> google.protobuf.duration_pb2.Duration:
        """Total speech length from which the age was estimated."""

    def __init__(
        self,
        *,
        age: builtins.int | None = ...,
        speech_length: google.protobuf.duration_pb2.Duration | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["_age", b"_age", "age", b"age", "speech_length", b"speech_length"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["_age", b"_age", "age", b"age", "speech_length", b"speech_length"]) -> None: ...
    def WhichOneof(self, oneof_group: typing.Literal["_age", b"_age"]) -> typing.Literal["age"] | None: ...

Global___EstimateResult: typing_extensions.TypeAlias = EstimateResult

@typing.final
class EstimateResponse(google.protobuf.message.Message):
    """The top-level message returned to the client by the <code>Estimate</code>
    method. It contains the result as one or more <code>EstimateResult</code>
    messages.
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESULTS_FIELD_NUMBER: builtins.int
    PROCESSED_AUDIO_LENGTH_FIELD_NUMBER: builtins.int
    @property
    def results(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[Global___EstimateResult]:
        """Sequential list of results corresponding to sequential list of voiceprints
        in <code>EstimateRequest</code>. Contains a single result when using audio.
        """

    @property
    def processed_audio_length(self) -> google.protobuf.duration_pb2.Duration:
        """When available, total length of the processed audio.
        Set only if audio is used in <code>EstimateRequest</code>.
        """

    def __init__(
        self,
        *,
        results: collections.abc.Iterable[Global___EstimateResult] | None = ...,
        processed_audio_length: google.protobuf.duration_pb2.Duration | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["processed_audio_length", b"processed_audio_length"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["processed_audio_length", b"processed_audio_length", "results", b"results"]) -> None: ...

Global___EstimateResponse: typing_extensions.TypeAlias = EstimateResponse



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc
import warnings

from phonexia.grpc.technologies.enhanced_speech_to_text_built_on_whisper.v1 import enhanced_speech_to_text_built_on_whisper_pb2 as phonexia_dot_grpc_dot_technologies_dot_enhanced__speech__to__text__built__on__whisper_dot_v1_dot_enhanced__speech__to__text__built__on__whisper__pb2

GRPC_GENERATED_VERSION = '1.76.0'
GRPC_VERSION = grpc.__version__
_version_not_supported = False

try:
    from grpc._utilities import first_version_is_lower
    _version_not_supported = first_version_is_lower(GRPC_VERSION, GRPC_GENERATED_VERSION)
except ImportError:
    _version_not_supported = True

if _version_not_supported:
    raise RuntimeError(
        f'The grpc package installed is at version {GRPC_VERSION},'
        + ' but the generated code in phonexia/grpc/technologies/enhanced_speech_to_text_built_on_whisper/v1/enhanced_speech_to_text_built_on_whisper_pb2_grpc.py depends on'
        + f' grpcio>={GRPC_GENERATED_VERSION}.'
        + f' Please upgrade your grpc module to grpcio>={GRPC_GENERATED_VERSION}'
        + f' or downgrade your generated code using grpcio-tools<={GRPC_VERSION}.'
    )


class SpeechToTextStub(object):
    """Service implementing speech-to-text transcription.
    """

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.Transcribe = channel.stream_stream(
                '/phonexia.grpc.technologies.enhanced_speech_to_text_built_on_whisper.v1.SpeechToText/Transcribe',
                request_serializer=phonexia_dot_grpc_dot_technologies_dot_enhanced__speech__to__text__built__on__whisper_dot_v1_dot_enhanced__speech__to__text__built__on__whisper__pb2.TranscribeRequest.SerializeToString,
                response_deserializer=phonexia_dot_grpc_dot_technologies_dot_enhanced__speech__to__text__built__on__whisper_dot_v1_dot_enhanced__speech__to__text__built__on__whisper__pb2.TranscribeResponse.FromString,
                _registered_method=True)
        self.Translate = channel.stream_stream(
                '/phonexia.grpc.technologies.enhanced_speech_to_text_built_on_whisper.v1.SpeechToText/Translate',
                request_serializer=phonexia_dot_grpc_dot_technologies_dot_enhanced__speech__to__text__built__on__whisper_dot_v1_dot_enhanced__speech__to__text__built__on__whisper__pb2.TranslateRequest.SerializeToString,
                response_deserializer=phonexia_dot_grpc_dot_technologies_dot_enhanced__speech__to__text__built__on__whisper_dot_v1_dot_enhanced__speech__to__text__built__on__whisper__pb2.TranslateResponse.FromString,
                _registered_method=True)
        self.ListSupportedLanguages = channel.unary_unary(
                '/phonexia.grpc.technologies.enhanced_speech_to_text_built_on_whisper.v1.SpeechToText/ListSupportedLanguages',
                request_serializer=phonexia_dot_grpc_dot_technologies_dot_enhanced__speech__to__text__built__on__whisper_dot_v1_dot_enhanced__speech__to__text__built__on__whisper__pb2.ListSupportedLanguagesRequest.SerializeToString,
                response_deserializer=phonexia_dot_grpc_dot_technologies_dot_enhanced__speech__to__text__built__on__whisper_dot_v1_dot_enhanced__speech__to__text__built__on__whisper__pb2.ListSupportedLanguagesResponse.FromString,
                _registered_method=True)


class SpeechToTextServicer(object):
    """Service implementing speech-to-text transcription.
    """

    def Transcribe(self, request_iterator, context):
        """Performs synchronous speech-to-text transcription. The transcription starts
        after the whole audio has been received.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Translate(self, request_iterator, context):
        """Performs synchronous speech-to-text translation. The translation starts
        after the whole audio has been received. Currently, the target language is limited
        to English only. The set of available source languages can be found by invoking
        the <code>ListSupportedLanguages</code> method.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ListSupportedLanguages(self, request, context):
        """Method to retrieve supported languages for transcription/translation.
        Models can be monolingual or multilingual. Multilingual models may be
        licensed to only a subset of all supported languages, in which case this
        method returns this limited subset.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_SpeechToTextServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'Transcribe': grpc.stream_stream_rpc_method_handler(
                    servicer.Transcribe,
                    request_deserializer=phonexia_dot_grpc_dot_technologies_dot_enhanced__speech__to__text__built__on__whisper_dot_v1_dot_enhanced__speech__to__text__built__on__whisper__pb2.TranscribeRequest.FromString,
                    response_serializer=phonexia_dot_grpc_dot_technologies_dot_enhanced__speech__to__text__built__on__whisper_dot_v1_dot_enhanced__speech__to__text__built__on__whisper__pb2.TranscribeResponse.SerializeToString,
            ),
            'Translate': grpc.stream_stream_rpc_method_handler(
                    servicer.Translate,
                    request_deserializer=phonexia_dot_grpc_dot_technologies_dot_enhanced__speech__to__text__built__on__whisper_dot_v1_dot_enhanced__speech__to__text__built__on__whisper__pb2.TranslateRequest.FromString,
                    response_serializer=phonexia_dot_grpc_dot_technologies_dot_enhanced__speech__to__text__built__on__whisper_dot_v1_dot_enhanced__speech__to__text__built__on__whisper__pb2.TranslateResponse.SerializeToString,
            ),
            'ListSupportedLanguages': grpc.unary_unary_rpc_method_handler(
                    servicer.ListSupportedLanguages,
                    request_deserializer=phonexia_dot_grpc_dot_technologies_dot_enhanced__speech__to__text__built__on__whisper_dot_v1_dot_enhanced__speech__to__text__built__on__whisper__pb2.ListSupportedLanguagesRequest.FromString,
                    response_serializer=phonexia_dot_grpc_dot_technologies_dot_enhanced__speech__to__text__built__on__whisper_dot_v1_dot_enhanced__speech__to__text__built__on__whisper__pb2.ListSupportedLanguagesResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'phonexia.grpc.technologies.enhanced_speech_to_text_built_on_whisper.v1.SpeechToText', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))
    server.add_registered_method_handlers('phonexia.grpc.technologies.enhanced_speech_to_text_built_on_whisper.v1.SpeechToText', rpc_method_handlers)


 # This class is part of an EXPERIMENTAL API.
class SpeechToText(object):
    """Service implementing speech-to-text transcription.
    """

    @staticmethod
    def Transcribe(request_iterator,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.stream_stream(
            request_iterator,
            target,
            '/phonexia.grpc.technologies.enhanced_speech_to_text_built_on_whisper.v1.SpeechToText/Transcribe',
            phonexia_dot_grpc_dot_technologies_dot_enhanced__speech__to__text__built__on__whisper_dot_v1_dot_enhanced__speech__to__text__built__on__whisper__pb2.TranscribeRequest.SerializeToString,
            phonexia_dot_grpc_dot_technologies_dot_enhanced__speech__to__text__built__on__whisper_dot_v1_dot_enhanced__speech__to__text__built__on__whisper__pb2.TranscribeResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def Translate(request_iterator,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.stream_stream(
            request_iterator,
            target,
            '/phonexia.grpc.technologies.enhanced_speech_to_text_built_on_whisper.v1.SpeechToText/Translate',
            phonexia_dot_grpc_dot_technologies_dot_enhanced__speech__to__text__built__on__whisper_dot_v1_dot_enhanced__speech__to__text__built__on__whisper__pb2.TranslateRequest.SerializeToString,
            phonexia_dot_grpc_dot_technologies_dot_enhanced__speech__to__text__built__on__whisper_dot_v1_dot_enhanced__speech__to__text__built__on__whisper__pb2.TranslateResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def ListSupportedLanguages(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/phonexia.grpc.technologies.enhanced_speech_to_text_built_on_whisper.v1.SpeechToText/ListSupportedLanguages',
            phonexia_dot_grpc_dot_technologies_dot_enhanced__speech__to__text__built__on__whisper_dot_v1_dot_enhanced__speech__to__text__built__on__whisper__pb2.ListSupportedLanguagesRequest.SerializeToString,
            phonexia_dot_grpc_dot_technologies_dot_enhanced__speech__to__text__built__on__whisper_dot_v1_dot_enhanced__speech__to__text__built__on__whisper__pb2.ListSupportedLanguagesResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
Copyright 2025 Phonexia s.r.o.

Licensed under the Apache License, Version 2.0 (the "License");
you may not use this file except in compliance with the License.
You may obtain a copy of the License at

    http://www.apache.org/licenses/LICENSE-2.0

Unless required by applicable law or agreed to in writing, software
distributed under the License is distributed on an "AS IS" BASIS,
WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
See the License for the specific language governing permissions and
limitations under the License.

Phonexia Language Identification gRPC API.
"""

import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.duration_pb2
import google.protobuf.internal.containers
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import phonexia.grpc.common.core_pb2
import sys
import typing

if sys.version_info >= (3, 10):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing.final
class IdentifyRequest(google.protobuf.message.Message):
    """The top level message sent by the client for the <code>Identify</code> method.
    The method accepts either Audio data or Languageprint.
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    AUDIO_FIELD_NUMBER: builtins.int
    CONFIG_FIELD_NUMBER: builtins.int
    LANGUAGEPRINT_FIELD_NUMBER: builtins.int
    @property
    def audio(self) -> phonexia.grpc.common.core_pb2.Audio:
        """Audio data in which language is to be identified.
        The audio should contain at least 0.3125 seconds of speech. If the audio contains less speech,
        the <code>scores</code> will be empty.
        """

    @property
    def config(self) -> Global___IdentifyConfig:
        """Configuration for the language identification."""

    @property
    def languageprint(self) -> Global___Languageprint:
        """Languageprint in which language is to be identified."""

    def __init__(
        self,
        *,
        audio: phonexia.grpc.common.core_pb2.Audio | None = ...,
        config: Global___IdentifyConfig | None = ...,
        languageprint: Global___Languageprint | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["audio", b"audio", "config", b"config", "languageprint", b"languageprint"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["audio", b"audio", "config", b"config", "languageprint", b"languageprint"]) -> None: ...

Global___IdentifyRequest: typing_extensions.TypeAlias = IdentifyRequest

@typing.final
class IdentifyResponse(google.protobuf.message.Message):
    """The top level message returned to the client by the <code>Identify</code> method."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESULT_FIELD_NUMBER: builtins.int
    PROCESSED_AUDIO_LENGTH_FIELD_NUMBER: builtins.int
    @property
    def result(self) -> Global___LanguageIdentificationResult:
        """Result of language identification."""

    @property
    def processed_audio_length(self) -> google.protobuf.duration_pb2.Duration:
        """When available, total length of the processed audio.
        Set only if this is the last response in the stream.
        """

    def __init__(
        self,
        *,
        result: Global___LanguageIdentificationResult | None = ...,
        processed_audio_length: google.protobuf.duration_pb2.Duration | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["processed_audio_length", b"processed_audio_length", "result", b"result"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["processed_audio_length", b"processed_audio_length", "result", b"result"]) -> None: ...

Global___IdentifyResponse: typing_extensions.TypeAlias = IdentifyResponse

@typing.final
class ListSupportedLanguagesRequest(google.protobuf.message.Message):
    """The top-level message sent by the client for the
    <code>ListSupportedLanguages</code> method.
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CONFIG_FIELD_NUMBER: builtins.int
    @property
    def config(self) -> Global___ListSupportedLanguagesConfig:
        """Configuration for the listing of supported languages."""

    def __init__(
        self,
        *,
        config: Global___ListSupportedLanguagesConfig | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["config", b"config"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["config", b"config"]) -> None: ...

Global___ListSupportedLanguagesRequest: typing_extensions.TypeAlias = ListSupportedLanguagesRequest

@typing.final
class ListSupportedLanguagesResponse(google.protobuf.message.Message):
    """The top-level message returned to the client by the
    <code>ListSupportedLanguages</code> method.
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SUPPORTED_LANGUAGES_FIELD_NUMBER: builtins.int
    MODIFIED_LANGUAGES_FIELD_NUMBER: builtins.int
    ADDED_LANGUAGES_FIELD_NUMBER: builtins.int
    @property
    def supported_languages(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]:
        """List of supported languages."""

    @property
    def modified_languages(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]:
        """Subset of <code>supported_languages</code> that were modified with custom data via
        language adaptation.
        """

    @property
    def added_languages(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]:
        """Subset of <code>supported_languages</code> that were added via language adaptation."""

    def __init__(
        self,
        *,
        supported_languages: collections.abc.Iterable[builtins.str] | None = ...,
        modified_languages: collections.abc.Iterable[builtins.str] | None = ...,
        added_languages: collections.abc.Iterable[builtins.str] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["added_languages", b"added_languages", "modified_languages", b"modified_languages", "supported_languages", b"supported_languages"]) -> None: ...

Global___ListSupportedLanguagesResponse: typing_extensions.TypeAlias = ListSupportedLanguagesResponse

@typing.final
class ExtractRequest(google.protobuf.message.Message):
    """The top level message sent by the client for the <code>Extract</code> method."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    AUDIO_FIELD_NUMBER: builtins.int
    CONFIG_FIELD_NUMBER: builtins.int
    @property
    def audio(self) -> phonexia.grpc.common.core_pb2.Audio:
        """Audio to extract the languageprint from.
        If the audio is in a raw format and the <code>config.speech_length</code> is
        set, the result can be returned before the whole audio was transferred if the
        requirements for speech length were met.
        The audio should contain at least 0.3125 seconds of speech. If the audio contains less speech,
        the resulted languageprint will be empty (contains 0s of speech).
        """

    @property
    def config(self) -> Global___ExtractConfig:
        """Configuration for the languageprint extraction."""

    def __init__(
        self,
        *,
        audio: phonexia.grpc.common.core_pb2.Audio | None = ...,
        config: Global___ExtractConfig | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["audio", b"audio", "config", b"config"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["audio", b"audio", "config", b"config"]) -> None: ...

Global___ExtractRequest: typing_extensions.TypeAlias = ExtractRequest

@typing.final
class ExtractResponse(google.protobuf.message.Message):
    """The top level message returned to the client by the <code>Extract</code> method."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESULT_FIELD_NUMBER: builtins.int
    PROCESSED_AUDIO_LENGTH_FIELD_NUMBER: builtins.int
    @property
    def result(self) -> Global___ExtractResult:
        """Result containing the extracted languageprint."""

    @property
    def processed_audio_length(self) -> google.protobuf.duration_pb2.Duration:
        """When available, total length of the processed audio.
        Set only if this is the last response in the stream.
        """

    def __init__(
        self,
        *,
        result: Global___ExtractResult | None = ...,
        processed_audio_length: google.protobuf.duration_pb2.Duration | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["processed_audio_length", b"processed_audio_length", "result", b"result"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["processed_audio_length", b"processed_audio_length", "result", b"result"]) -> None: ...

Global___ExtractResponse: typing_extensions.TypeAlias = ExtractResponse

@typing.final
class AdaptRequest(google.protobuf.message.Message):
    """The top-level message sent by the client for the <code>Adapt</code> method."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ADAPTATION_UNITS_FIELD_NUMBER: builtins.int
    @property
    def adaptation_units(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[Global___AdaptationUnit]:
        """Data (languageprints, metadata) used for the supervised adaptation."""

    def __init__(
        self,
        *,
        adaptation_units: collections.abc.Iterable[Global___AdaptationUnit] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["adaptation_units", b"adaptation_units"]) -> None: ...

Global___AdaptRequest: typing_extensions.TypeAlias = AdaptRequest

@typing.final
class AdaptResponse(google.protobuf.message.Message):
    """The top-level message returned to the client by the <code>Adapt</code> method."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESULT_FIELD_NUMBER: builtins.int
    @property
    def result(self) -> Global___AdaptationResult:
        """Result of language adaptation."""

    def __init__(
        self,
        *,
        result: Global___AdaptationResult | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["result", b"result"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["result", b"result"]) -> None: ...

Global___AdaptResponse: typing_extensions.TypeAlias = AdaptResponse

@typing.final
class IdentifyConfig(google.protobuf.message.Message):
    """Message used for configuration of the <code>Identify</code> method."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SPEECH_LENGTH_FIELD_NUMBER: builtins.int
    LANGUAGES_FIELD_NUMBER: builtins.int
    GROUPS_FIELD_NUMBER: builtins.int
    ADAPTATION_PROFILE_FIELD_NUMBER: builtins.int
    @property
    def speech_length(self) -> google.protobuf.duration_pb2.Duration:
        """Specifies the maximum speech length from which the languages will be identified.
        If there is less speech in the audio than the specified duration, the languages
        will be identified from the entire audio. This option is applicable only for Audio
        data.
        """

    @property
    def languages(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[Global___Language]:
        """Specify which languages can be used for language identification.
        Choose only from list of supported languages, which can be retrieved at
        <code>ListSupportedLanguages</code>. Choosing desired languages redistributes
        the probabilities of excluded languages into the rest of languages relative
        to their scores. Excluding a dialect of a language may however result in
        inaccurate scores for other dialects in cases when the excluded dialect would
        have a probability score close to 1. Leaving this field empty is the same as
        selecting every supported language.
        """

    @property
    def groups(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[Global___LanguageGroup]:
        """Create custom groups of languages and assign them a common identifier.
        By defining a group a new entity that encapsulates the group languages is
        created. This group holds the scores of the individual languages as well as
        their sum. One of the use cases for using groups may be grouping individual
        language dialects into one encapsulating group. Groups of languages mustn't
        intersect, that means a language can only be part of at most one group.
        """

    @property
    def adaptation_profile(self) -> Global___AdaptationProfile:
        """Adapt the model with language adaptation obtained via the <code>Adapt</code>
        method. Be careful to only send this field with the first message of the stream,
        as it is several kilobytes in size.
        """

    def __init__(
        self,
        *,
        speech_length: google.protobuf.duration_pb2.Duration | None = ...,
        languages: collections.abc.Iterable[Global___Language] | None = ...,
        groups: collections.abc.Iterable[Global___LanguageGroup] | None = ...,
        adaptation_profile: Global___AdaptationProfile | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["adaptation_profile", b"adaptation_profile", "speech_length", b"speech_length"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["adaptation_profile", b"adaptation_profile", "groups", b"groups", "languages", b"languages", "speech_length", b"speech_length"]) -> None: ...

Global___IdentifyConfig: typing_extensions.TypeAlias = IdentifyConfig

@typing.final
class ListSupportedLanguagesConfig(google.protobuf.message.Message):
    """Message used for configuration of the <code>ListSupportedLanguages</code> method."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ADAPTATION_PROFILE_FIELD_NUMBER: builtins.int
    @property
    def adaptation_profile(self) -> Global___AdaptationProfile:
        """Adapt the model with language adaptation obtained via the <code>Adapt</code>
        method. The returned list will then contain all built-in languages as well as
        languages modified and newly added using the language adaptation.
        """

    def __init__(
        self,
        *,
        adaptation_profile: Global___AdaptationProfile | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["adaptation_profile", b"adaptation_profile"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["adaptation_profile", b"adaptation_profile"]) -> None: ...

Global___ListSupportedLanguagesConfig: typing_extensions.TypeAlias = ListSupportedLanguagesConfig

@typing.final
class ExtractConfig(google.protobuf.message.Message):
    """Message used for configuration of the <code>Extract</code> method."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SPEECH_LENGTH_FIELD_NUMBER: builtins.int
    @property
    def speech_length(self) -> google.protobuf.duration_pb2.Duration:
        """Specifies the maximum speech length from which the languageprint may be extracted.
        If there is less speech in the audio than the specified duration, the languageprint
        will be extracted from the entire audio.
        """

    def __init__(
        self,
        *,
        speech_length: google.protobuf.duration_pb2.Duration | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["speech_length", b"speech_length"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["speech_length", b"speech_length"]) -> None: ...

Global___ExtractConfig: typing_extensions.TypeAlias = ExtractConfig

@typing.final
class Language(google.protobuf.message.Message):
    """Message for selecting specific language."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    LANGUAGE_CODE_FIELD_NUMBER: builtins.int
    language_code: builtins.str
    """Language code in RFC 5646 format."""
    def __init__(
        self,
        *,
        language_code: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["language_code", b"language_code"]) -> None: ...

Global___Language: typing_extensions.TypeAlias = Language

@typing.final
class LanguageGroup(google.protobuf.message.Message):
    """Message defining language group. Group several languages and assigns them common
    identifier. Defining group produces score for the individual languages as well as
    for the language groups.
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    IDENTIFIER_FIELD_NUMBER: builtins.int
    LANGUAGE_CODES_FIELD_NUMBER: builtins.int
    identifier: builtins.str
    """Identifier of created group.
    This identifier will be used in <code>LanguageIdentificationScore</code>.
    Group identifier must be unique among all groups and languages.
    """
    @property
    def language_codes(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]:
        """Set of languages forming this group."""

    def __init__(
        self,
        *,
        identifier: builtins.str = ...,
        language_codes: collections.abc.Iterable[builtins.str] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["identifier", b"identifier", "language_codes", b"language_codes"]) -> None: ...

Global___LanguageGroup: typing_extensions.TypeAlias = LanguageGroup

@typing.final
class Languageprint(google.protobuf.message.Message):
    """Represents the result from languageprint extraction."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CONTENT_FIELD_NUMBER: builtins.int
    content: builtins.bytes
    """Languageprint data encoded in UBJSON format."""
    def __init__(
        self,
        *,
        content: builtins.bytes = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["content", b"content"]) -> None: ...

Global___Languageprint: typing_extensions.TypeAlias = Languageprint

@typing.final
class LanguageIdentificationResult(google.protobuf.message.Message):
    """Message representing the result of language identification."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SPEECH_LENGTH_FIELD_NUMBER: builtins.int
    SCORES_FIELD_NUMBER: builtins.int
    @property
    def speech_length(self) -> google.protobuf.duration_pb2.Duration:
        """Speech length from which the languageprint was extracted."""

    @property
    def scores(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[Global___LanguageIdentificationScore]:
        """List of scores for each selected language and language group.
        This list holds N elements, where:
        N = (number of supported languages) + (number of groups) - (number of languages
        defined within groups).

        Example: For 140 supported languages and 2 groups each containing 4 unique
        languages this field holds: 140 + 2 - (2 * 4) = 134 elements including 132
        languages and 2 groups. Scores of the individual languages from the groups
        are embedded within the groups.
        """

    def __init__(
        self,
        *,
        speech_length: google.protobuf.duration_pb2.Duration | None = ...,
        scores: collections.abc.Iterable[Global___LanguageIdentificationScore] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["speech_length", b"speech_length"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["scores", b"scores", "speech_length", b"speech_length"]) -> None: ...

Global___LanguageIdentificationResult: typing_extensions.TypeAlias = LanguageIdentificationResult

@typing.final
class LanguageIdentificationScore(google.protobuf.message.Message):
    """Score for a single language or language group."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    class _IdentifierType:
        ValueType = typing.NewType("ValueType", builtins.int)
        V: typing_extensions.TypeAlias = ValueType

    class _IdentifierTypeEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[LanguageIdentificationScore._IdentifierType.ValueType], builtins.type):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
        LANGUAGE: LanguageIdentificationScore._IdentifierType.ValueType  # 0
        """The identifier specifies a single language (built-in or adapted)"""
        GROUP: LanguageIdentificationScore._IdentifierType.ValueType  # 1
        """The identifier specifies a user-defined group of languages."""

    class IdentifierType(_IdentifierType, metaclass=_IdentifierTypeEnumTypeWrapper):
        """Enumeration of supported identifier types."""

    LANGUAGE: LanguageIdentificationScore.IdentifierType.ValueType  # 0
    """The identifier specifies a single language (built-in or adapted)"""
    GROUP: LanguageIdentificationScore.IdentifierType.ValueType  # 1
    """The identifier specifies a user-defined group of languages."""

    IDENTIFIER_FIELD_NUMBER: builtins.int
    PROBABILITY_FIELD_NUMBER: builtins.int
    LANGUAGES_FIELD_NUMBER: builtins.int
    IDENTIFIER_TYPE_FIELD_NUMBER: builtins.int
    identifier: builtins.str
    """This field contains either a language identifier or a language group identifier.
    Language identifiers may be specified by a RFC 5646 code for built-in languages or
    by a custom identifier for languages added via language adaptation.
    """
    probability: builtins.float
    """Score for this language or language group.
    The score represents the probability of the input belonging to a particular
    language/group.
    Language group probability is the sum of the probabilities of its languages.
    """
    identifier_type: Global___LanguageIdentificationScore.IdentifierType.ValueType
    """This field explicitly identifies the score as belonging to either an individual
    language or a language group.
    """
    @property
    def languages(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[Global___LanguageIdentificationScore]:
        """This field is only set for language groups.
        Scores for individual languages that this group is comprised of can be found in
        this field.
        """

    def __init__(
        self,
        *,
        identifier: builtins.str = ...,
        probability: builtins.float = ...,
        languages: collections.abc.Iterable[Global___LanguageIdentificationScore] | None = ...,
        identifier_type: Global___LanguageIdentificationScore.IdentifierType.ValueType = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["identifier", b"identifier", "identifier_type", b"identifier_type", "languages", b"languages", "probability", b"probability"]) -> None: ...

Global___LanguageIdentificationScore: typing_extensions.TypeAlias = LanguageIdentificationScore

@typing.final
class ExtractResult(google.protobuf.message.Message):
    """A languageprint extraction result."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SPEECH_LENGTH_FIELD_NUMBER: builtins.int
    LANGUAGEPRINT_FIELD_NUMBER: builtins.int
    @property
    def speech_length(self) -> google.protobuf.duration_pb2.Duration:
        """Speech length from which the languageprint was extracted."""

    @property
    def languageprint(self) -> Global___Languageprint:
        """Extracted languageprint."""

    def __init__(
        self,
        *,
        speech_length: google.protobuf.duration_pb2.Duration | None = ...,
        languageprint: Global___Languageprint | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["languageprint", b"languageprint", "speech_length", b"speech_length"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["languageprint", b"languageprint", "speech_length", b"speech_length"]) -> None: ...

Global___ExtractResult: typing_extensions.TypeAlias = ExtractResult

@typing.final
class AdaptationUnit(google.protobuf.message.Message):
    """A unit used for language adaptation. Language adaptation is typically performed with
    many adaptation units. Each unit must be assigned to either an existing language to
    adapt its accuracy on new data, or to a new identifier to create a new language in
    the language identification.
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    LANGUAGEPRINT_FIELD_NUMBER: builtins.int
    LANGUAGE_FIELD_NUMBER: builtins.int
    @property
    def languageprint(self) -> Global___Languageprint:
        """Languageprint containing the data for adaptation."""

    @property
    def language(self) -> Global___Language:
        """The language contained in the languageprint recording.
        By selecting a built-in language, this language will be modified for better
        performance on custom data.
        By selecting a new language, the system will add this language to the possible
        languages for language identification.
        """

    def __init__(
        self,
        *,
        languageprint: Global___Languageprint | None = ...,
        language: Global___Language | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["language", b"language", "languageprint", b"languageprint"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["language", b"language", "languageprint", b"languageprint"]) -> None: ...

Global___AdaptationUnit: typing_extensions.TypeAlias = AdaptationUnit

@typing.final
class AdaptationProfile(google.protobuf.message.Message):
    """Message containing the language adaptation profile. We recommend to store the
    original audio data, as the <code>AdaptationProfile</code> created for a specific
    version of Language Identification may not work with a different version and
    thus the <code>AdaptationProfile</code> would need to be created anew.
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CONTENT_FIELD_NUMBER: builtins.int
    content: builtins.bytes
    """The data of the language adaptation profile."""
    def __init__(
        self,
        *,
        content: builtins.bytes = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["content", b"content"]) -> None: ...

Global___AdaptationProfile: typing_extensions.TypeAlias = AdaptationProfile

@typing.final
class AdaptationResult(google.protobuf.message.Message):
    """Message representing the result of language adaptation."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ADAPTATION_PROFILE_FIELD_NUMBER: builtins.int
    MODIFIED_LANGUAGES_FIELD_NUMBER: builtins.int
    ADDED_LANGUAGES_FIELD_NUMBER: builtins.int
    @property
    def adaptation_profile(self) -> Global___AdaptationProfile:
        """A structure containing the resulting adaptation data for the technology."""

    @property
    def modified_languages(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]:
        """Built-in languages that were modified by the adaptation."""

    @property
    def added_languages(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]:
        """New languages that were added by the adaptation."""

    def __init__(
        self,
        *,
        adaptation_profile: Global___AdaptationProfile | None = ...,
        modified_languages: collections.abc.Iterable[builtins.str] | None = ...,
        added_languages: collections.abc.Iterable[builtins.str] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["adaptation_profile", b"adaptation_profile"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["adaptation_profile", b"adaptation_profile", "added_languages", b"added_languages", "modified_languages", b"modified_languages"]) -> None: ...

Global___AdaptationResult: typing_extensions.TypeAlias = AdaptationResult



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
Copyright 2025 Phonexia s.r.o.

Licensed under the Apache License, Version 2.0 (the "License");
you may not use this file except in compliance with the License.
You may obtain a copy of the License at

    http://www.apache.org/licenses/LICENSE-2.0

Unless required by applicable law or agreed to in writing, software
distributed under the License is distributed on an "AS IS" BASIS,
WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
See the License for the specific language governing permissions and
limitations under the License.

Phonexia Deepfake Detection gRPC API.
"""

import builtins
import google.protobuf.descriptor
import google.protobuf.duration_pb2
import google.protobuf.message
import phonexia.grpc.common.core_pb2
import sys
import typing

if sys.version_info >= (3, 10):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing.final
class DetectRequest(google.protobuf.message.Message):
    """The top level message sent by the client for the <code>Detect</code> method."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    AUDIO_FIELD_NUMBER: builtins.int
    CONFIG_FIELD_NUMBER: builtins.int
    @property
    def audio(self) -> phonexia.grpc.common.core_pb2.Audio:
        """Audio data for deepfake detection.
        The audio should contain at least 3 seconds of continuous speech.
        If there is not enough speech, the <code>result</code> will not be present
        in the output.
        """

    @property
    def config(self) -> Global___DetectConfig:
        """Configuration for the deepfake detection"""

    def __init__(
        self,
        *,
        audio: phonexia.grpc.common.core_pb2.Audio | None = ...,
        config: Global___DetectConfig | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["audio", b"audio", "config", b"config"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["audio", b"audio", "config", b"config"]) -> None: ...

Global___DetectRequest: typing_extensions.TypeAlias = DetectRequest

@typing.final
class DetectConfig(google.protobuf.message.Message):
    """Configuration for the deepfake detection."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SPEECH_LENGTH_FIELD_NUMBER: builtins.int
    @property
    def speech_length(self) -> google.protobuf.duration_pb2.Duration:
        """Maximum speech length to process from the audio."""

    def __init__(
        self,
        *,
        speech_length: google.protobuf.duration_pb2.Duration | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["speech_length", b"speech_length"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["speech_length", b"speech_length"]) -> None: ...

Global___DetectConfig: typing_extensions.TypeAlias = DetectConfig

@typing.final
class DetectResponse(google.protobuf.message.Message):
    """The top level message returned to the client by the <code>Detect</code> method."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESULT_FIELD_NUMBER: builtins.int
    PROCESSED_AUDIO_LENGTH_FIELD_NUMBER: builtins.int
    @property
    def result(self) -> Global___DetectResult:
        """Result of deepfake detection. Will not be present if the audio contains
        less than 3 seconds of continuous speech.
        """

    @property
    def processed_audio_length(self) -> google.protobuf.duration_pb2.Duration:
        """Total length of the processed audio."""

    def __init__(
        self,
        *,
        result: Global___DetectResult | None = ...,
        processed_audio_length: google.protobuf.duration_pb2.Duration | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["_result", b"_result", "processed_audio_length", b"processed_audio_length", "result", b"result"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["_result", b"_result", "processed_audio_length", b"processed_audio_length", "result", b"result"]) -> None: ...
    def WhichOneof(self, oneof_group: typing.Literal["_result", b"_result"]) -> typing.Literal["result"] | None: ...

Global___DetectResponse: typing_extensions.TypeAlias = DetectResponse

@typing.final
class DetectResult(google.protobuf.message.Message):
    """Message representing the result of deepfake detection."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SCORE_FIELD_NUMBER: builtins.int
    SPEECH_LENGTH_FIELD_NUMBER: builtins.int
    score: builtins.float
    """Log-likelihood ratio (LLR) of the deepfake detection. The score is a
    floating-point value. A value greater than 0 indicates the audio is likely
    a deepfake, while a value less than 0 indicates the audio is likely not a
    deepfake.
    """
    @property
    def speech_length(self) -> google.protobuf.duration_pb2.Duration:
        """Total speech length the deepfake detector used for evaluation."""

    def __init__(
        self,
        *,
        score: builtins.float = ...,
        speech_length: google.protobuf.duration_pb2.Duration | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["speech_length", b"speech_length"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["score", b"score", "speech_length", b"speech_length"]) -> None: ...

Global___DetectResult: typing_extensions.TypeAlias = DetectResult



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
Copyright 2025 Phonexia s.r.o.

Licensed under the Apache License, Version 2.0 (the "License");
you may not use this file except in compliance with the License.
You may obtain a copy of the License at

    http://www.apache.org/licenses/LICENSE-2.0

Unless required by applicable law or agreed to in writing, software
distributed under the License is distributed on an "AS IS" BASIS,
WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
See the License for the specific language governing permissions and
limitations under the License.

Phonexia Emotion Recognition gRPC API.
"""

import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.duration_pb2
import google.protobuf.internal.containers
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import phonexia.grpc.common.core_pb2
import sys
import typing

if sys.version_info >= (3, 10):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing.final
class RecognizeRequest(google.protobuf.message.Message):
    """The top-level message sent by the client for the <code>Recognize</code> method."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    AUDIO_FIELD_NUMBER: builtins.int
    CONFIG_FIELD_NUMBER: builtins.int
    @property
    def audio(self) -> phonexia.grpc.common.core_pb2.Audio:
        """Audio data to recognize the emotions of speakers from.
        If the audio is in a raw format and the <code>config.speech_length</code> is set,
        the service will stop processing the audio once the required speech length is met.
        Otherwise, the service will process the whole audio. There is no minimum audio length limit.
        """

    @property
    def config(self) -> Global___RecognizeConfig:
        """Configuration for the emotion detection."""

    def __init__(
        self,
        *,
        audio: phonexia.grpc.common.core_pb2.Audio | None = ...,
        config: Global___RecognizeConfig | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["_config", b"_config", "audio", b"audio", "config", b"config"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["_config", b"_config", "audio", b"audio", "config", b"config"]) -> None: ...
    def WhichOneof(self, oneof_group: typing.Literal["_config", b"_config"]) -> typing.Literal["config"] | None: ...

Global___RecognizeRequest: typing_extensions.TypeAlias = RecognizeRequest

@typing.final
class RecognizeConfig(google.protobuf.message.Message):
    """The configuration message for the <code>Recognize</code> method."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SPEECH_LENGTH_FIELD_NUMBER: builtins.int
    @property
    def speech_length(self) -> google.protobuf.duration_pb2.Duration:
        """Specifies the maximum speech length from which the emotions will be recognized. 
        If there is less speech in the audio than the specified
        duration, the emotions will be recognized from the entire audio.
        """

    def __init__(
        self,
        *,
        speech_length: google.protobuf.duration_pb2.Duration | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["speech_length", b"speech_length"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["speech_length", b"speech_length"]) -> None: ...

Global___RecognizeConfig: typing_extensions.TypeAlias = RecognizeConfig

@typing.final
class RecognizeResponse(google.protobuf.message.Message):
    """The top-level message returned to the client by the <code>Recognize</code> method."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESULT_FIELD_NUMBER: builtins.int
    PROCESSED_AUDIO_LENGTH_FIELD_NUMBER: builtins.int
    @property
    def result(self) -> Global___RecognizeResult:
        """Result containing the recognized emotions with their scores."""

    @property
    def processed_audio_length(self) -> google.protobuf.duration_pb2.Duration:
        """Total length of the processed audio."""

    def __init__(
        self,
        *,
        result: Global___RecognizeResult | None = ...,
        processed_audio_length: google.protobuf.duration_pb2.Duration | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["processed_audio_length", b"processed_audio_length", "result", b"result"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["processed_audio_length", b"processed_audio_length", "result", b"result"]) -> None: ...

Global___RecognizeResponse: typing_extensions.TypeAlias = RecognizeResponse

@typing.final
class RecognizeResult(google.protobuf.message.Message):
    """Message containing the result of emotion recognition."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SPEECH_LENGTH_FIELD_NUMBER: builtins.int
    SCORES_FIELD_NUMBER: builtins.int
    @property
    def speech_length(self) -> google.protobuf.duration_pb2.Duration:
        """Total speech length from which the emotions were recognized."""

    @property
    def scores(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[Global___EmotionScore]:
        """List of emotions and their probabilities.
        It can be empty if the input does not contain any speech.
        """

    def __init__(
        self,
        *,
        speech_length: google.protobuf.duration_pb2.Duration | None = ...,
        scores: collections.abc.Iterable[Global___EmotionScore] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["speech_length", b"speech_length"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["scores", b"scores", "speech_length", b"speech_length"]) -> None: ...

Global___RecognizeResult: typing_extensions.TypeAlias = RecognizeResult

@typing.final
class EmotionScore(google.protobuf.message.Message):
    """Message containing the emotion type and its probability."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    class _EmotionType:
        ValueType = typing.NewType("ValueType", builtins.int)
        V: typing_extensions.TypeAlias = ValueType

    class _EmotionTypeEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[EmotionScore._EmotionType.ValueType], builtins.type):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
        ANGRY: EmotionScore._EmotionType.ValueType  # 0
        SAD: EmotionScore._EmotionType.ValueType  # 1
        HAPPY: EmotionScore._EmotionType.ValueType  # 2
        NEUTRAL: EmotionScore._EmotionType.ValueType  # 3

    class EmotionType(_EmotionType, metaclass=_EmotionTypeEnumTypeWrapper):
        """Supported emotion types."""

    ANGRY: EmotionScore.EmotionType.ValueType  # 0
    SAD: EmotionScore.EmotionType.ValueType  # 1
    HAPPY: EmotionScore.EmotionType.ValueType  # 2
    NEUTRAL: EmotionScore.EmotionType.ValueType  # 3

    EMOTION_FIELD_NUMBER: builtins.int
    PROBABILITY_FIELD_NUMBER: builtins.int
    emotion: Global___EmotionScore.EmotionType.ValueType
    """Recognized emotion from the supported types."""
    probability: builtins.float
    """Probability score associated with the recognized emotion."""
    def __init__(
        self,
        *,
        emotion: Global___EmotionScore.EmotionType.ValueType = ...,
        probability: builtins.float = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["emotion", b"emotion", "probability", b"probability"]) -> None: ...

Global___EmotionScore: typing_extensions.TypeAlias = EmotionScore



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: phonexia/grpc/technologies/deepfake_detection/v1/deepfake_detection.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'phonexia/grpc/technologies/deepfake_detection/v1/deepfake_detection.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import duration_pb2 as google_dot_protobuf_dot_duration__pb2
from phonexia.grpc.common import core_pb2 as phonexia_dot_grpc_dot_common_dot_core__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nIphonexia/grpc/technologies/deepfake_detection/v1/deepfake_detection.proto\x12\x30phonexia.grpc.technologies.deepfake_detection.v1\x1a\x1egoogle/protobuf/duration.proto\x1a\x1fphonexia/grpc/common/core.proto\"\x8b\x01\n\rDetectRequest\x12*\n\x05\x61udio\x18\x01 \x01(\x0b\x32\x1b.phonexia.grpc.common.Audio\x12N\n\x06\x63onfig\x18\x02 \x01(\x0b\x32>.phonexia.grpc.technologies.deepfake_detection.v1.DetectConfig\"@\n\x0c\x44\x65tectConfig\x12\x30\n\rspeech_length\x18\x01 \x01(\x0b\x32\x19.google.protobuf.Duration\"\xab\x01\n\x0e\x44\x65tectResponse\x12S\n\x06result\x18\x01 \x01(\x0b\x32>.phonexia.grpc.technologies.deepfake_detection.v1.DetectResultH\x00\x88\x01\x01\x12\x39\n\x16processed_audio_length\x18\x02 \x01(\x0b\x32\x19.google.protobuf.DurationB\t\n\x07_result\"O\n\x0c\x44\x65tectResult\x12\r\n\x05score\x18\x01 \x01(\x02\x12\x30\n\rspeech_length\x18\x02 \x01(\x0b\x32\x19.google.protobuf.Duration2\xa3\x01\n\x11\x44\x65\x65pfakeDetection\x12\x8d\x01\n\x06\x44\x65tect\x12?.phonexia.grpc.technologies.deepfake_detection.v1.DetectRequest\x1a@.phonexia.grpc.technologies.deepfake_detection.v1.DetectResponse(\x01\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'phonexia.grpc.technologies.deepfake_detection.v1.deepfake_detection_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  DESCRIPTOR._loaded_options = None
  _globals['_DETECTREQUEST']._serialized_start=193
  _globals['_DETECTREQUEST']._serialized_end=332
  _globals['_DETECTCONFIG']._serialized_start=334
  _globals['_DETECTCONFIG']._serialized_end=398
  _globals['_DETECTRESPONSE']._serialized_start=401
  _globals['_DETECTRESPONSE']._serialized_end=572
  _globals['_DETECTRESULT']._serialized_start=574
  _globals['_DETECTRESULT']._serialized_end=653
  _globals['_DEEPFAKEDETECTION']._serialized_start=656
  _globals['_DEEPFAKEDETECTION']._serialized_end=819
# @@protoc_insertion_point(module_scope)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
Copyright 2025 Phonexia s.r.o.

Licensed under the Apache License, Version 2.0 (the "License");
you may not use this file except in compliance with the License.
You may obtain a copy of the License at

    http://www.apache.org/licenses/LICENSE-2.0

Unless required by applicable law or agreed to in writing, software
distributed under the License is distributed on an "AS IS" BASIS,
WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
See the License for the specific language governing permissions and
limitations under the License.

Phonexia Voice Activity Detection gRPC API.
"""

import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.duration_pb2
import google.protobuf.internal.containers
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import phonexia.grpc.common.core_pb2
import sys
import typing

if sys.version_info >= (3, 10):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing.final
class DetectRequest(google.protobuf.message.Message):
    """The top-level message sent by the client for the <code>Detect</code>
    method.
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    AUDIO_FIELD_NUMBER: builtins.int
    @property
    def audio(self) -> phonexia.grpc.common.core_pb2.Audio:
        """Audio to be processed.
        The audio should have minimum length of 0.8 seconds. If the audio is shorter,
        the <code>segments</code> will be empty.
        """

    def __init__(
        self,
        *,
        audio: phonexia.grpc.common.core_pb2.Audio | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["audio", b"audio"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["audio", b"audio"]) -> None: ...

Global___DetectRequest: typing_extensions.TypeAlias = DetectRequest

@typing.final
class DetectResponse(google.protobuf.message.Message):
    """The top-level message returned to the client by the <code>Detect</code>
    method.
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SPEECH_LENGTH_FIELD_NUMBER: builtins.int
    SEGMENTS_FIELD_NUMBER: builtins.int
    PROCESSED_AUDIO_LENGTH_FIELD_NUMBER: builtins.int
    @property
    def speech_length(self) -> google.protobuf.duration_pb2.Duration:
        """Total speech length detected in the audio."""

    @property
    def segments(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[Global___Segment]:
        """List of detected voice segments. Will be empty if the audio is shorter than 0.8 seconds."""

    @property
    def processed_audio_length(self) -> google.protobuf.duration_pb2.Duration:
        """Total length of the processed audio."""

    def __init__(
        self,
        *,
        speech_length: google.protobuf.duration_pb2.Duration | None = ...,
        segments: collections.abc.Iterable[Global___Segment] | None = ...,
        processed_audio_length: google.protobuf.duration_pb2.Duration | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["processed_audio_length", b"processed_audio_length", "speech_length", b"speech_length"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["processed_audio_length", b"processed_audio_length", "segments", b"segments", "speech_length", b"speech_length"]) -> None: ...

Global___DetectResponse: typing_extensions.TypeAlias = DetectResponse

@typing.final
class Segment(google.protobuf.message.Message):
    """Detected voice segment."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    class _SegmentType:
        ValueType = typing.NewType("ValueType", builtins.int)
        V: typing_extensions.TypeAlias = ValueType

    class _SegmentTypeEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[Segment._SegmentType.ValueType], builtins.type):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
        VOICE: Segment._SegmentType.ValueType  # 0

    class SegmentType(_SegmentType, metaclass=_SegmentTypeEnumTypeWrapper):
        """Enumeration of supported segment types."""

    VOICE: Segment.SegmentType.ValueType  # 0

    TYPE_FIELD_NUMBER: builtins.int
    START_TIME_FIELD_NUMBER: builtins.int
    END_TIME_FIELD_NUMBER: builtins.int
    type: Global___Segment.SegmentType.ValueType
    """Type of the segment."""
    @property
    def start_time(self) -> google.protobuf.duration_pb2.Duration:
        """Timestamp specifying the beginning of the segment."""

    @property
    def end_time(self) -> google.protobuf.duration_pb2.Duration:
        """Timestamp specifying the end of the segment."""

    def __init__(
        self,
        *,
        type: Global___Segment.SegmentType.ValueType = ...,
        start_time: google.protobuf.duration_pb2.Duration | None = ...,
        end_time: google.protobuf.duration_pb2.Duration | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["end_time", b"end_time", "start_time", b"start_time"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["end_time", b"end_time", "start_time", b"start_time", "type", b"type"]) -> None: ...

Global___Segment: typing_extensions.TypeAlias = Segment



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: phonexia/grpc/technologies/speaker_identification/v1/speaker_identification.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'phonexia/grpc/technologies/speaker_identification/v1/speaker_identification.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from phonexia.grpc.common import core_pb2 as phonexia_dot_grpc_dot_common_dot_core__pb2
from google.protobuf import duration_pb2 as google_dot_protobuf_dot_duration__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nQphonexia/grpc/technologies/speaker_identification/v1/speaker_identification.proto\x12\x34phonexia.grpc.technologies.speaker_identification.v1\x1a\x1fphonexia/grpc/common/core.proto\x1a\x1egoogle/protobuf/duration.proto\"\x82\x01\n\x0e\x43ompareRequest\x12\x37\n\rvoiceprints_a\x18\x01 \x03(\x0b\x32 .phonexia.grpc.common.Voiceprint\x12\x37\n\rvoiceprints_b\x18\x02 \x03(\x0b\x32 .phonexia.grpc.common.Voiceprint\"?\n\x0f\x43ompareResponse\x12,\n\x06scores\x18\x01 \x01(\x0b\x32\x1c.phonexia.grpc.common.Matrix\"\x91\x01\n\x0e\x45xtractRequest\x12*\n\x05\x61udio\x18\x01 \x01(\x0b\x32\x1b.phonexia.grpc.common.Audio\x12S\n\x06\x63onfig\x18\x02 \x01(\x0b\x32\x43.phonexia.grpc.technologies.speaker_identification.v1.ExtractConfig\"c\n\rExtractConfig\x12\x30\n\rspeech_length\x18\x01 \x01(\x0b\x32\x19.google.protobuf.Duration\x12 \n\x18\x65nable_vector_voiceprint\x18\x02 \x01(\x08\"\xb0\x01\n\rExtractResult\x12\x30\n\rspeech_length\x18\x01 \x01(\x0b\x32\x19.google.protobuf.Duration\x12\x34\n\nvoiceprint\x18\x02 \x01(\x0b\x32 .phonexia.grpc.common.Voiceprint\x12\x37\n\x11vector_voiceprint\x18\x03 \x01(\x0b\x32\x1c.phonexia.grpc.common.Vector\"\xa1\x01\n\x0f\x45xtractResponse\x12S\n\x06result\x18\x01 \x01(\x0b\x32\x43.phonexia.grpc.technologies.speaker_identification.v1.ExtractResult\x12\x39\n\x16processed_audio_length\x18\x02 \x01(\x0b\x32\x19.google.protobuf.Duration\"E\n\x0cMergeRequest\x12\x35\n\x0bvoiceprints\x18\x01 \x03(\x0b\x32 .phonexia.grpc.common.Voiceprint\"w\n\rMergeResponse\x12\x30\n\rspeech_length\x18\x01 \x01(\x0b\x32\x19.google.protobuf.Duration\x12\x34\n\nvoiceprint\x18\x02 \x01(\x0b\x32 .phonexia.grpc.common.Voiceprint\"G\n\x0e\x43onvertRequest\x12\x35\n\x0bvoiceprints\x18\x01 \x03(\x0b\x32 .phonexia.grpc.common.Voiceprint\"K\n\x0f\x43onvertResponse\x12\x38\n\x12vector_voiceprints\x18\x01 \x03(\x0b\x32\x1c.phonexia.grpc.common.Vector2\xb3\x01\n\x14VoiceprintComparison\x12\x9a\x01\n\x07\x43ompare\x12\x44.phonexia.grpc.technologies.speaker_identification.v1.CompareRequest\x1a\x45.phonexia.grpc.technologies.speaker_identification.v1.CompareResponse(\x01\x30\x01\x32\xb1\x01\n\x14VoiceprintExtraction\x12\x98\x01\n\x07\x45xtract\x12\x44.phonexia.grpc.technologies.speaker_identification.v1.ExtractRequest\x1a\x45.phonexia.grpc.technologies.speaker_identification.v1.ExtractResponse(\x01\x32\xa6\x01\n\x11VoiceprintMerging\x12\x90\x01\n\x05Merge\x12\x42.phonexia.grpc.technologies.speaker_identification.v1.MergeRequest\x1a\x43.phonexia.grpc.technologies.speaker_identification.v1.MergeResponse2\xb3\x01\n\x14VoiceprintConversion\x12\x9a\x01\n\x07\x43onvert\x12\x44.phonexia.grpc.technologies.speaker_identification.v1.ConvertRequest\x1a\x45.phonexia.grpc.technologies.speaker_identification.v1.ConvertResponse(\x01\x30\x01\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'phonexia.grpc.technologies.speaker_identification.v1.speaker_identification_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  DESCRIPTOR._loaded_options = None
  _globals['_COMPAREREQUEST']._serialized_start=205
  _globals['_COMPAREREQUEST']._serialized_end=335
  _globals['_COMPARERESPONSE']._serialized_start=337
  _globals['_COMPARERESPONSE']._serialized_end=400
  _globals['_EXTRACTREQUEST']._serialized_start=403
  _globals['_EXTRACTREQUEST']._serialized_end=548
  _globals['_EXTRACTCONFIG']._serialized_start=550
  _globals['_EXTRACTCONFIG']._serialized_end=649
  _globals['_EXTRACTRESULT']._serialized_start=652
  _globals['_EXTRACTRESULT']._serialized_end=828
  _globals['_EXTRACTRESPONSE']._serialized_start=831
  _globals['_EXTRACTRESPONSE']._serialized_end=992
  _globals['_MERGEREQUEST']._serialized_start=994
  _globals['_MERGEREQUEST']._serialized_end=1063
  _globals['_MERGERESPONSE']._serialized_start=1065
  _globals['_MERGERESPONSE']._serialized_end=1184
  _globals['_CONVERTREQUEST']._serialized_start=1186
  _globals['_CONVERTREQUEST']._serialized_end=1257
  _globals['_CONVERTRESPONSE']._serialized_start=1259
  _globals['_CONVERTRESPONSE']._serialized_end=1334
  _globals['_VOICEPRINTCOMPARISON']._serialized_start=1337
  _globals['_VOICEPRINTCOMPARISON']._serialized_end=1516
  _globals['_VOICEPRINTEXTRACTION']._serialized_start=1519
  _globals['_VOICEPRINTEXTRACTION']._serialized_end=1696
  _globals['_VOICEPRINTMERGING']._serialized_start=1699
  _globals['_VOICEPRINTMERGING']._serialized_end=1865
  _globals['_VOICEPRINTCONVERSION']._serialized_start=1868
  _globals['_VOICEPRINTCONVERSION']._serialized_end=2047
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: phonexia/grpc/technologies/language_identification/v1/language_identification.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'phonexia/grpc/technologies/language_identification/v1/language_identification.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import duration_pb2 as google_dot_protobuf_dot_duration__pb2
from phonexia.grpc.common import core_pb2 as phonexia_dot_grpc_dot_common_dot_core__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nSphonexia/grpc/technologies/language_identification/v1/language_identification.proto\x12\x35phonexia.grpc.technologies.language_identification.v1\x1a\x1egoogle/protobuf/duration.proto\x1a\x1fphonexia/grpc/common/core.proto\"\xf1\x01\n\x0fIdentifyRequest\x12*\n\x05\x61udio\x18\x01 \x01(\x0b\x32\x1b.phonexia.grpc.common.Audio\x12U\n\x06\x63onfig\x18\x02 \x01(\x0b\x32\x45.phonexia.grpc.technologies.language_identification.v1.IdentifyConfig\x12[\n\rlanguageprint\x18\x03 \x01(\x0b\x32\x44.phonexia.grpc.technologies.language_identification.v1.Languageprint\"\xb2\x01\n\x10IdentifyResponse\x12\x63\n\x06result\x18\x01 \x01(\x0b\x32S.phonexia.grpc.technologies.language_identification.v1.LanguageIdentificationResult\x12\x39\n\x16processed_audio_length\x18\x02 \x01(\x0b\x32\x19.google.protobuf.Duration\"\x84\x01\n\x1dListSupportedLanguagesRequest\x12\x63\n\x06\x63onfig\x18\x01 \x01(\x0b\x32S.phonexia.grpc.technologies.language_identification.v1.ListSupportedLanguagesConfig\"r\n\x1eListSupportedLanguagesResponse\x12\x1b\n\x13supported_languages\x18\x01 \x03(\t\x12\x1a\n\x12modified_languages\x18\x02 \x03(\t\x12\x17\n\x0f\x61\x64\x64\x65\x64_languages\x18\x03 \x03(\t\"\x92\x01\n\x0e\x45xtractRequest\x12*\n\x05\x61udio\x18\x01 \x01(\x0b\x32\x1b.phonexia.grpc.common.Audio\x12T\n\x06\x63onfig\x18\x02 \x01(\x0b\x32\x44.phonexia.grpc.technologies.language_identification.v1.ExtractConfig\"\xa2\x01\n\x0f\x45xtractResponse\x12T\n\x06result\x18\x01 \x01(\x0b\x32\x44.phonexia.grpc.technologies.language_identification.v1.ExtractResult\x12\x39\n\x16processed_audio_length\x18\x02 \x01(\x0b\x32\x19.google.protobuf.Duration\"o\n\x0c\x41\x64\x61ptRequest\x12_\n\x10\x61\x64\x61ptation_units\x18\x01 \x03(\x0b\x32\x45.phonexia.grpc.technologies.language_identification.v1.AdaptationUnit\"h\n\rAdaptResponse\x12W\n\x06result\x18\x01 \x01(\x0b\x32G.phonexia.grpc.technologies.language_identification.v1.AdaptationResult\"\xd2\x02\n\x0eIdentifyConfig\x12\x30\n\rspeech_length\x18\x01 \x01(\x0b\x32\x19.google.protobuf.Duration\x12R\n\tlanguages\x18\x02 \x03(\x0b\x32?.phonexia.grpc.technologies.language_identification.v1.Language\x12T\n\x06groups\x18\x03 \x03(\x0b\x32\x44.phonexia.grpc.technologies.language_identification.v1.LanguageGroup\x12\x64\n\x12\x61\x64\x61ptation_profile\x18\x04 \x01(\x0b\x32H.phonexia.grpc.technologies.language_identification.v1.AdaptationProfile\"\x84\x01\n\x1cListSupportedLanguagesConfig\x12\x64\n\x12\x61\x64\x61ptation_profile\x18\x01 \x01(\x0b\x32H.phonexia.grpc.technologies.language_identification.v1.AdaptationProfile\"A\n\rExtractConfig\x12\x30\n\rspeech_length\x18\x01 \x01(\x0b\x32\x19.google.protobuf.Duration\"!\n\x08Language\x12\x15\n\rlanguage_code\x18\x01 \x01(\t\";\n\rLanguageGroup\x12\x12\n\nidentifier\x18\x01 \x01(\t\x12\x16\n\x0elanguage_codes\x18\x02 \x03(\t\" \n\rLanguageprint\x12\x0f\n\x07\x63ontent\x18\x01 \x01(\x0c\"\xb4\x01\n\x1cLanguageIdentificationResult\x12\x30\n\rspeech_length\x18\x01 \x01(\x0b\x32\x19.google.protobuf.Duration\x12\x62\n\x06scores\x18\x02 \x03(\x0b\x32R.phonexia.grpc.technologies.language_identification.v1.LanguageIdentificationScore\"\xd4\x02\n\x1bLanguageIdentificationScore\x12\x12\n\nidentifier\x18\x01 \x01(\t\x12\x13\n\x0bprobability\x18\x02 \x01(\x02\x12\x65\n\tlanguages\x18\x03 \x03(\x0b\x32R.phonexia.grpc.technologies.language_identification.v1.LanguageIdentificationScore\x12z\n\x0fidentifier_type\x18\x04 \x01(\x0e\x32\x61.phonexia.grpc.technologies.language_identification.v1.LanguageIdentificationScore.IdentifierType\")\n\x0eIdentifierType\x12\x0c\n\x08LANGUAGE\x10\x00\x12\t\n\x05GROUP\x10\x01\"\x9e\x01\n\rExtractResult\x12\x30\n\rspeech_length\x18\x01 \x01(\x0b\x32\x19.google.protobuf.Duration\x12[\n\rlanguageprint\x18\x02 \x01(\x0b\x32\x44.phonexia.grpc.technologies.language_identification.v1.Languageprint\"\xc0\x01\n\x0e\x41\x64\x61ptationUnit\x12[\n\rlanguageprint\x18\x01 \x01(\x0b\x32\x44.phonexia.grpc.technologies.language_identification.v1.Languageprint\x12Q\n\x08language\x18\x02 \x01(\x0b\x32?.phonexia.grpc.technologies.language_identification.v1.Language\"$\n\x11\x41\x64\x61ptationProfile\x12\x0f\n\x07\x63ontent\x18\x01 \x01(\x0c\"\xad\x01\n\x10\x41\x64\x61ptationResult\x12\x64\n\x12\x61\x64\x61ptation_profile\x18\x01 \x01(\x0b\x32H.phonexia.grpc.technologies.language_identification.v1.AdaptationProfile\x12\x1a\n\x12modified_languages\x18\x02 \x03(\t\x12\x17\n\x0f\x61\x64\x64\x65\x64_languages\x18\x03 \x03(\t2\xb4\x05\n\x16LanguageIdentification\x12\x9d\x01\n\x08Identify\x12\x46.phonexia.grpc.technologies.language_identification.v1.IdentifyRequest\x1aG.phonexia.grpc.technologies.language_identification.v1.IdentifyResponse(\x01\x12\xc5\x01\n\x16ListSupportedLanguages\x12T.phonexia.grpc.technologies.language_identification.v1.ListSupportedLanguagesRequest\x1aU.phonexia.grpc.technologies.language_identification.v1.ListSupportedLanguagesResponse\x12\x9a\x01\n\x07\x45xtract\x12\x45.phonexia.grpc.technologies.language_identification.v1.ExtractRequest\x1a\x46.phonexia.grpc.technologies.language_identification.v1.ExtractResponse(\x01\x12\x94\x01\n\x05\x41\x64\x61pt\x12\x43.phonexia.grpc.technologies.language_identification.v1.AdaptRequest\x1a\x44.phonexia.grpc.technologies.language_identification.v1.AdaptResponse(\x01\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'phonexia.grpc.technologies.language_identification.v1.language_identification_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  DESCRIPTOR._loaded_options = None
  _globals['_IDENTIFYREQUEST']._serialized_start=208
  _globals['_IDENTIFYREQUEST']._serialized_end=449
  _globals['_IDENTIFYRESPONSE']._serialized_start=452
  _globals['_IDENTIFYRESPONSE']._serialized_end=630
  _globals['_LISTSUPPORTEDLANGUAGESREQUEST']._serialized_start=633
  _globals['_LISTSUPPORTEDLANGUAGESREQUEST']._serialized_end=765
  _globals['_LISTSUPPORTEDLANGUAGESRESPONSE']._serialized_start=767
  _globals['_LISTSUPPORTEDLANGUAGESRESPONSE']._serialized_end=881
  _globals['_EXTRACTREQUEST']._serialized_start=884
  _globals['_EXTRACTREQUEST']._serialized_end=1030
  _globals['_EXTRACTRESPONSE']._serialized_start=1033
  _globals['_EXTRACTRESPONSE']._serialized_end=1195
  _globals['_ADAPTREQUEST']._serialized_start=1197
  _globals['_ADAPTREQUEST']._serialized_end=1308
  _globals['_ADAPTRESPONSE']._serialized_start=1310
  _globals['_ADAPTRESPONSE']._serialized_end=1414
  _globals['_IDENTIFYCONFIG']._serialized_start=1417
  _globals['_IDENTIFYCONFIG']._serialized_end=1755
  _globals['_LISTSUPPORTEDLANGUAGESCONFIG']._serialized_start=1758
  _globals['_LISTSUPPORTEDLANGUAGESCONFIG']._serialized_end=1890
  _globals['_EXTRACTCONFIG']._serialized_start=1892
  _globals['_EXTRACTCONFIG']._serialized_end=1957
  _globals['_LANGUAGE']._serialized_start=1959
  _globals['_LANGUAGE']._serialized_end=1992
  _globals['_LANGUAGEGROUP']._serialized_start=1994
  _globals['_LANGUAGEGROUP']._serialized_end=2053
  _globals['_LANGUAGEPRINT']._serialized_start=2055
  _globals['_LANGUAGEPRINT']._serialized_end=2087
  _globals['_LANGUAGEIDENTIFICATIONRESULT']._serialized_start=2090
  _globals['_LANGUAGEIDENTIFICATIONRESULT']._serialized_end=2270
  _globals['_LANGUAGEIDENTIFICATIONSCORE']._serialized_start=2273
  _globals['_LANGUAGEIDENTIFICATIONSCORE']._serialized_end=2613
  _globals['_LANGUAGEIDENTIFICATIONSCORE_IDENTIFIERTYPE']._serialized_start=2572
  _globals['_LANGUAGEIDENTIFICATIONSCORE_IDENTIFIERTYPE']._serialized_end=2613
  _globals['_EXTRACTRESULT']._serialized_start=2616
  _globals['_EXTRACTRESULT']._serialized_end=2774
  _globals['_ADAPTATIONUNIT']._serialized_start=2777
  _globals['_ADAPTATIONUNIT']._serialized_end=2969
  _globals['_ADAPTATIONPROFILE']._serialized_start=2971
  _globals['_ADAPTATIONPROFILE']._serialized_end=3007
  _globals['_ADAPTATIONRESULT']._serialized_start=3010
  _globals['_ADAPTATIONRESULT']._serialized_end=3183
  _globals['_LANGUAGEIDENTIFICATION']._serialized_start=3186
  _globals['_LANGUAGEIDENTIFICATION']._serialized_end=3878
# @@protoc_insertion_point(module_scope)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
Copyright 2025 Phonexia s.r.o.

Licensed under the Apache License, Version 2.0 (the "License");
you may not use this file except in compliance with the License.
You may obtain a copy of the License at

    http://www.apache.org/licenses/LICENSE-2.0

Unless required by applicable law or agreed to in writing, software
distributed under the License is distributed on an "AS IS" BASIS,
WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
See the License for the specific language governing permissions and
limitations under the License.

Phonexia Speaker Diarization gRPC API
"""

import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.duration_pb2
import google.protobuf.internal.containers
import google.protobuf.message
import phonexia.grpc.common.core_pb2
import sys
import typing

if sys.version_info >= (3, 10):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing.final
class DiarizeRequest(google.protobuf.message.Message):
    """The top-level message sent by the client for the <code>Diarize</code> method."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    AUDIO_FIELD_NUMBER: builtins.int
    CONFIG_FIELD_NUMBER: builtins.int
    @property
    def audio(self) -> phonexia.grpc.common.core_pb2.Audio:
        """Audio to be diarized.
        The audio should have minimum length of 0.8 seconds. If the audio is shorter,
        the <code>segments</code> will be empty.
        """

    @property
    def config(self) -> Global___DiarizeConfig:
        """Speaker diarization configuration."""

    def __init__(
        self,
        *,
        audio: phonexia.grpc.common.core_pb2.Audio | None = ...,
        config: Global___DiarizeConfig | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["audio", b"audio", "config", b"config"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["audio", b"audio", "config", b"config"]) -> None: ...

Global___DiarizeRequest: typing_extensions.TypeAlias = DiarizeRequest

@typing.final
class DiarizeConfig(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    MAX_SPEAKERS_FIELD_NUMBER: builtins.int
    TOTAL_SPEAKERS_FIELD_NUMBER: builtins.int
    max_speakers: builtins.int
    """Upper limit for the number of speakers in the audio.
    The value must be larger than 0.
    If omitted, the default value is set to 100.
    """
    total_speakers: builtins.int
    """Enforces exact number of speakers in the audio. If set, it overwrites
    <code>max_speakers</code>. If not set, the number of speakers
    is detected automatically, with upper limit defined by
    <code>max_speakers</code>.
    """
    def __init__(
        self,
        *,
        max_speakers: builtins.int | None = ...,
        total_speakers: builtins.int | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["_max_speakers", b"_max_speakers", "_total_speakers", b"_total_speakers", "max_speakers", b"max_speakers", "total_speakers", b"total_speakers"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["_max_speakers", b"_max_speakers", "_total_speakers", b"_total_speakers", "max_speakers", b"max_speakers", "total_speakers", b"total_speakers"]) -> None: ...
    @typing.overload
    def WhichOneof(self, oneof_group: typing.Literal["_max_speakers", b"_max_speakers"]) -> typing.Literal["max_speakers"] | None: ...
    @typing.overload
    def WhichOneof(self, oneof_group: typing.Literal["_total_speakers", b"_total_speakers"]) -> typing.Literal["total_speakers"] | None: ...

Global___DiarizeConfig: typing_extensions.TypeAlias = DiarizeConfig

@typing.final
class DiarizeResponse(google.protobuf.message.Message):
    """The top-level message returned to the client by the <code>Diarize</code>
    method.
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SPEAKERS_COUNT_FIELD_NUMBER: builtins.int
    SEGMENTS_FIELD_NUMBER: builtins.int
    PROCESSED_AUDIO_LENGTH_FIELD_NUMBER: builtins.int
    SPEECH_LENGTH_FIELD_NUMBER: builtins.int
    speakers_count: builtins.int
    """Detected number of speakers in the audio."""
    @property
    def segments(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[Global___Segment]:
        """List of detected segments in the audio. Will be empty if the audio is shorter than 0.8 seconds."""

    @property
    def processed_audio_length(self) -> google.protobuf.duration_pb2.Duration:
        """Total length of the processed audio."""

    @property
    def speech_length(self) -> google.protobuf.duration_pb2.Duration:
        """Total Speech length of the processed audio."""

    def __init__(
        self,
        *,
        speakers_count: builtins.int = ...,
        segments: collections.abc.Iterable[Global___Segment] | None = ...,
        processed_audio_length: google.protobuf.duration_pb2.Duration | None = ...,
        speech_length: google.protobuf.duration_pb2.Duration | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["processed_audio_length", b"processed_audio_length", "speech_length", b"speech_length"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["processed_audio_length", b"processed_audio_length", "segments", b"segments", "speakers_count", b"speakers_count", "speech_length", b"speech_length"]) -> None: ...

Global___DiarizeResponse: typing_extensions.TypeAlias = DiarizeResponse

@typing.final
class Segment(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SPEAKER_ID_FIELD_NUMBER: builtins.int
    START_TIME_FIELD_NUMBER: builtins.int
    END_TIME_FIELD_NUMBER: builtins.int
    speaker_id: builtins.int
    """Identifier of a speaker in the segment."""
    @property
    def start_time(self) -> google.protobuf.duration_pb2.Duration:
        """Start time of the segment."""

    @property
    def end_time(self) -> google.protobuf.duration_pb2.Duration:
        """End time of the segment."""

    def __init__(
        self,
        *,
        speaker_id: builtins.int = ...,
        start_time: google.protobuf.duration_pb2.Duration | None = ...,
        end_time: google.protobuf.duration_pb2.Duration | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["end_time", b"end_time", "start_time", b"start_time"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["end_time", b"end_time", "speaker_id", b"speaker_id", "start_time", b"start_time"]) -> None: ...

Global___Segment: typing_extensions.TypeAlias = Segment
